@@ -1,18 +1,18 @@
 /*
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at https://mozilla.org/MPL/2.0/.
  */
 
 
 "use strict";
 
-/* global Components: false, DirPaneHasFocus: false, GetSelectedAddressesFromDirTree: false, GetSelectedAddresses: false */
+/* global DirPaneHasFocus: false, GetSelectedAddressesFromDirTree: false, GetSelectedAddresses: false */
 
-Components.utils.import("resource://enigmail/funcs.jsm"); /*global EnigmailFuncs: false */
-Components.utils.import("resource://enigmail/windows.jsm"); /*global EnigmailWindows: false */
+var EnigmailFuncs = ChromeUtils.import("chrome://enigmail/content/modules/funcs.jsm").EnigmailFuncs;
+var EnigmailWindows = ChromeUtils.import("chrome://enigmail/content/modules/windows.jsm").EnigmailWindows;
 
-var Enigmail = {
+var EnigmailAbOverlay = {
   createRuleFromAddress: function(emailAddressNode) {
     if (emailAddressNode) {
       var r = new RegExp("^" + emailAddressNode.protocol);
@@ -32,3 +32,9 @@ var Enigmail = {
       EnigmailWindows.createNewRule(window, EnigmailFuncs.stripEmail(emailAddress).replace(/,/g, " "));
   }
 };
+
+window.addEventListener("unload-enigmail", function _unload() {
+    window.removeEventListener("unload-enigmail", _unload, false);
+    EnigmailAbOverlay = undefined;
+  },
+  false);
\ No newline at end of file
