@@ -1,8 +1,8 @@
-/*global Components: false, EnigmailFiles: false, EnigmailCore: false, EnigmailApp: false, EnigmailDialog: false, EnigmailWindows: false, EnigmailTime: false */
+/*global EnigmailFiles: false, EnigmailCore: false, EnigmailApp: false, EnigmailDialog: false, EnigmailWindows: false, EnigmailTime: false */
 /*
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at https://mozilla.org/MPL/2.0/.
  */
 
 /**
@@ -17,30 +17,30 @@
 // WARNING: This module functions must not be loaded in overlays to standard functionality!
 
 // Many of these components are not used in this file, but are instead used in other files that are loaded together with EnigmailCommon
-Components.utils.import("resource://enigmail/core.jsm"); /*global EnigmailCore: false */
-Components.utils.import("resource://enigmail/funcs.jsm"); /*global EnigmailFuncs: false */
-Components.utils.import("resource://enigmail/keyEditor.jsm"); /*global EnigmailKeyEditor: false */
-Components.utils.import("resource://enigmail/key.jsm"); /*global EnigmailKey: false */
-Components.utils.import("resource://enigmail/log.jsm"); /*global EnigmailLog: false */
-Components.utils.import("resource://enigmail/prefs.jsm"); /*global EnigmailPrefs: false */
-Components.utils.import("resource://enigmail/os.jsm"); /*global EnigmailOS: false */
-Components.utils.import("resource://enigmail/locale.jsm"); /*global EnigmailLocale: false */
-Components.utils.import("resource://enigmail/data.jsm"); /*global EnigmailData: false */
-Components.utils.import("resource://enigmail/files.jsm"); /*global EnigmailFiles: false */
-Components.utils.import("resource://enigmail/app.jsm"); /*global EnigmailApp: false */
-Components.utils.import("resource://enigmail/dialog.jsm"); /*global EnigmailDialog: false */
-Components.utils.import("resource://enigmail/windows.jsm"); /*global EnigmailWindows: false */
-Components.utils.import("resource://enigmail/time.jsm"); /*global EnigmailTime: false */
-Components.utils.import("resource://enigmail/timer.jsm"); /*global EnigmailTimer: false */
-Components.utils.import("resource://enigmail/keyRing.jsm"); /*global EnigmailKeyRing: false */
-Components.utils.import("resource://enigmail/trust.jsm"); /*global EnigmailTrust: false */
-Components.utils.import("resource://enigmail/constants.jsm"); /*global EnigmailConstants: false */
-Components.utils.import("resource://enigmail/errorHandling.jsm"); /*global EnigmailErrorHandling: false */
-Components.utils.import("resource://enigmail/keyserver.jsm"); /*global EnigmailKeyServer: false */
-Components.utils.import("resource://enigmail/events.jsm"); /*global EnigmailEvents: false */
-Components.utils.import("resource://enigmail/gpg.jsm"); /*global EnigmailGpg: false */
-Components.utils.import("resource://enigmail/promise.jsm"); /*global Promise: false */
-Components.utils.import("resource://enigmail/gpgAgent.jsm"); /*global EnigmailGpgAgent: false */
+var EnigmailCore = ChromeUtils.import("chrome://enigmail/content/modules/core.jsm").EnigmailCore;
+var EnigmailFuncs = ChromeUtils.import("chrome://enigmail/content/modules/funcs.jsm").EnigmailFuncs;
+var EnigmailKeyEditor = ChromeUtils.import("chrome://enigmail/content/modules/keyEditor.jsm").EnigmailKeyEditor;
+var EnigmailKey = ChromeUtils.import("chrome://enigmail/content/modules/key.jsm").EnigmailKey;
+var EnigmailLog = ChromeUtils.import("chrome://enigmail/content/modules/log.jsm").EnigmailLog;
+var EnigmailPrefs = ChromeUtils.import("chrome://enigmail/content/modules/prefs.jsm").EnigmailPrefs;
+var EnigmailOS = ChromeUtils.import("chrome://enigmail/content/modules/os.jsm").EnigmailOS;
+var EnigmailLocale = ChromeUtils.import("chrome://enigmail/content/modules/locale.jsm").EnigmailLocale;
+var EnigmailData = ChromeUtils.import("chrome://enigmail/content/modules/data.jsm").EnigmailData;
+var EnigmailFiles = ChromeUtils.import("chrome://enigmail/content/modules/files.jsm").EnigmailFiles;
+var EnigmailApp = ChromeUtils.import("chrome://enigmail/content/modules/app.jsm").EnigmailApp;
+var EnigmailDialog = ChromeUtils.import("chrome://enigmail/content/modules/dialog.jsm").EnigmailDialog;
+var EnigmailWindows = ChromeUtils.import("chrome://enigmail/content/modules/windows.jsm").EnigmailWindows;
+var EnigmailTime = ChromeUtils.import("chrome://enigmail/content/modules/time.jsm").EnigmailTime;
+var EnigmailTimer = ChromeUtils.import("chrome://enigmail/content/modules/timer.jsm").EnigmailTimer;
+var EnigmailKeyRing = ChromeUtils.import("chrome://enigmail/content/modules/keyRing.jsm").EnigmailKeyRing;
+var EnigmailTrust = ChromeUtils.import("chrome://enigmail/content/modules/trust.jsm").EnigmailTrust;
+var EnigmailConstants = ChromeUtils.import("chrome://enigmail/content/modules/constants.jsm").EnigmailConstants;
+var EnigmailErrorHandling = ChromeUtils.import("chrome://enigmail/content/modules/errorHandling.jsm").EnigmailErrorHandling;
+var EnigmailKeyServer = ChromeUtils.import("chrome://enigmail/content/modules/keyserver.jsm").EnigmailKeyServer;
+var EnigmailEvents = ChromeUtils.import("chrome://enigmail/content/modules/events.jsm").EnigmailEvents;
+var EnigmailGpg = ChromeUtils.import("chrome://enigmail/content/modules/gpg.jsm").EnigmailGpg;
+var EnigmailGpgAgent = ChromeUtils.import("chrome://enigmail/content/modules/gpgAgent.jsm").EnigmailGpgAgent;
+var EnigmailStreams = ChromeUtils.import("chrome://enigmail/content/modules/streams.jsm").EnigmailStreams;
 
 
 // The compatible Enigmime version
@@ -81,10 +81,6 @@ const ENIG_IOSERVICE_CONTRACTID = "@mozilla.org/network/io-service;1";
 const ENIG_C = Components.classes;
 const ENIG_I = Components.interfaces;
 
-// Key algorithms
-const ENIG_KEYTYPE_DSA = 1;
-const ENIG_KEYTYPE_RSA = 2;
-
 
 // field ID's of key list (as described in the doc/DETAILS file in the GnuPG distribution)
 const ENIG_KEY_TRUST = 1;
@@ -105,18 +101,15 @@ const ENIG_KEY_NOT_VALID = ENIG_KEY_EXPIRED + ENIG_KEY_REVOKED + ENIG_KEY_INVALI
 
 
 // GUI List: The corresponding image to set the "active" flag / checkbox
-const ENIG_IMG_NOT_SELECTED = "chrome://enigmail/content/check0.png";
-const ENIG_IMG_SELECTED = "chrome://enigmail/content/check1.png";
-const ENIG_IMG_DISABLED = "chrome://enigmail/content/check2.png";
+const ENIG_IMG_NOT_SELECTED = "chrome://enigmail/content/ui/check0.png";
+const ENIG_IMG_SELECTED = "chrome://enigmail/content/ui/check1.png";
+const ENIG_IMG_DISABLED = "chrome://enigmail/content/ui/check2.png";
 
 
-// Interfaces
-const nsIEnigmail = ENIG_I.nsIEnigmail;
-
 // Encryption flags
-if (nsIEnigmail) {
-  const ENIG_SIGN = nsIEnigmail.SEND_SIGNED;
-  const ENIG_ENCRYPT = nsIEnigmail.SEND_ENCRYPTED;
+if (EnigmailConstants) {
+  const ENIG_SIGN = EnigmailConstants.SEND_SIGNED;
+  const ENIG_ENCRYPT = EnigmailConstants.SEND_ENCRYPTED;
   const ENIG_ENCRYPT_OR_SIGN = ENIG_ENCRYPT | ENIG_SIGN;
 }
 
@@ -187,7 +180,7 @@ function EnigReadURLContents(url, maxBytes) {
   if (!ioServ)
     throw Components.results.NS_ERROR_FAILURE;
 
-  var fileChannel = ioServ.newChannel(url, null, null);
+  var fileChannel = EnigmailStreams.createChannel(url);
 
   var rawInStream = fileChannel.open();
 
@@ -261,19 +254,10 @@ function EnigConfirm(mesg, okLabel, cancelLabel) {
 }
 
 
-function EnigConfirmPref(mesg, prefText, okLabel, cancelLabel) {
-  return EnigmailDialog.confirmPref(window, mesg, prefText, okLabel, cancelLabel);
-}
-
 function EnigError(mesg) {
   return gEnigPromptSvc.alert(window, EnigGetString("enigError"), mesg);
 }
 
-function EnigPrefWindow(showBasic, clientType, selectTab) {
-  EnigmailLog.DEBUG("enigmailCommon.js: EnigPrefWindow\n");
-  EnigmailWindows.openPrefWindow(window, showBasic, selectTab);
-}
-
 
 function EnigHelpWindow(source) {
   EnigmailWindows.openHelpWindow(source);
@@ -308,8 +292,7 @@ function EnigSetRadioPref(prefName, optionElementIds) {
         groupElement.value = prefValue;
       }
     }
-  }
-  catch (ex) {}
+  } catch (ex) {}
 }
 
 function EnigSavePrefs() {
@@ -327,8 +310,7 @@ function EnigGetDefaultPref(prefName) {
     EnigmailPrefs.getPrefBranch().lockPref(prefName);
     prefValue = EnigGetPref(prefName);
     EnigmailPrefs.getPrefBranch().unlockPref(prefName);
-  }
-  catch (ex) {}
+  } catch (ex) {}
 
   return prefValue;
 }
@@ -337,10 +319,6 @@ function EnigSetPref(prefName, value) {
   return EnigmailPrefs.setPref(prefName, value);
 }
 
-function EnigGetSignMsg(identity) {
-  EnigmailFuncs.getSignMsg(identity);
-}
-
 
 function EnigConvertFromUnicode(text, charset) {
   EnigmailLog.DEBUG("enigmailCommon.js: EnigConvertFromUnicode: " + charset + "\n");
@@ -357,8 +335,7 @@ function EnigConvertFromUnicode(text, charset) {
     unicodeConv.charset = charset;
     return unicodeConv.ConvertFromUnicode(text);
 
-  }
-  catch (ex) {
+  } catch (ex) {
     EnigmailLog.DEBUG("enigmailCommon.js: EnigConvertFromUnicode: caught an exception\n");
 
     return text;
@@ -379,8 +356,7 @@ function EnigConvertToUnicode(text, charset) {
     unicodeConv.charset = charset;
     return unicodeConv.ConvertToUnicode(text);
 
-  }
-  catch (ex) {
+  } catch (ex) {
     EnigmailLog.DEBUG("enigmailCommon.js: EnigConvertToUnicode: caught an exception while converting'" + text + "' to " + charset + "\n");
     return text;
   }
@@ -403,9 +379,9 @@ function EnigFormatFpr(fingerprint) {
 function EnigGetWindowOptions() {
   var winOptions = [];
   if (window.location.search) {
-    var optList = window.location.search.substr(1).split(/\&/);
+    var optList = window.location.search.substr(1).split(/&/);
     for (var i = 0; i < optList.length; i++) {
-      var anOption = optList[i].split(/\=/);
+      var anOption = optList[i].split(new RegExp("="));
       winOptions[anOption[0]] = unescape(anOption[1]);
     }
   }
@@ -437,12 +413,6 @@ function EnigGetString(aStr) {
   return EnigmailLocale.getString(aStr, (arguments.length > 1 ? argList : null));
 }
 
-// Remove all quoted strings (and angle brackets) from a list of email
-// addresses, returning a list of pure email addresses
-function EnigStripEmail(mailAddrs) {
-  return EnigmailFuncs.stripEmail(mailAddrs);
-}
-
 
 //get path for temporary directory (e.g. /tmp, C:\TEMP)
 function EnigGetTempDir() {
@@ -511,7 +481,7 @@ function EnigRevokeKey(keyId, userId, callbackFunc) {
   if (!enigmailSvc)
     return false;
 
-  var userDesc = "0x" + keyId.substr(-8, 8) + " - " + userId;
+  var userDesc = "0x" + keyId + " - " + userId;
   if (!EnigConfirm(EnigGetString("revokeKeyQuestion", userDesc), EnigGetString("keyMan.button.revokeKey")))
     return false;
 
@@ -524,8 +494,7 @@ function EnigRevokeKey(keyId, userId, callbackFunc) {
       EnigAlert(EnigGetString("noTempDir"));
       return false;
     }
-  }
-  catch (ex) {}
+  } catch (ex) {}
   revFile.append("revkey.asc");
 
   EnigmailKeyEditor.genRevokeCert(window, "0x" + keyId, revFile, "0", "",
@@ -536,13 +505,11 @@ function EnigRevokeKey(keyId, userId, callbackFunc) {
         return;
       }
       var errorMsgObj = {};
-      var keyList = {};
-      var r = EnigmailKeyRing.importKeyFromFile(revFile, errorMsgObj, keyList);
+      var r = EnigmailKeyRing.importKeyFromFile(revFile, errorMsgObj);
       revFile.remove(false);
       if (r !== 0) {
         EnigAlert(EnigGetString("revokeKeyFailed") + "\n\n" + EnigConvertGpgToUnicode(errorMsgObj.value));
-      }
-      else {
+      } else {
         EnigAlert(EnigGetString("revokeKeyOk"));
       }
       if (callbackFunc) {
@@ -565,8 +532,8 @@ function EnigGetFilePath(nsFileObj) {
 }
 
 function EnigCreateRevokeCert(keyId, userId, callbackFunc) {
-  var defaultFileName = userId.replace(/[<\>]/g, "");
-  defaultFileName += " (0x" + keyId.substr(-8, 8) + ") rev.asc";
+  var defaultFileName = userId.replace(/[<>]/g, "");
+  defaultFileName += " (0x" + keyId + ") rev.asc";
   var outFile = EnigFilePicker(EnigGetString("saveRevokeCertAs"),
     "", true, "*.asc",
     defaultFileName, [EnigGetString("asciiArmorFile"), "*.asc"]);
@@ -580,8 +547,7 @@ function EnigCreateRevokeCert(keyId, userId, callbackFunc) {
     function _revokeCertCb(exitCode, errorMsg) {
       if (exitCode !== 0) {
         EnigAlert(EnigGetString("revokeCertFailed") + "\n\n" + errorMsg);
-      }
-      else {
+      } else {
         EnigAlert(EnigGetString("revokeCertOK"));
       }
 
@@ -614,8 +580,6 @@ function enigGetService(aURL, aInterface) {
     default:
       return ENIG_C[aURL].getService();
   }
-
-  return null;
 }
 
 function EnigCollapseAdvanced(obj, attribute, dummy) {
@@ -633,7 +597,7 @@ function EnigOpenUrlExternally(uri) {
   let eps = ENIG_C["@mozilla.org/uriloader/external-protocol-service;1"].
   getService(ENIG_I.nsIExternalProtocolService);
 
-  eps.loadUrl(uri, null);
+  eps.loadURI(uri, null);
 }
 
 function EnigOpenURL(event, hrefObj) {
@@ -650,8 +614,7 @@ function EnigOpenURL(event, hrefObj) {
     EnigOpenUrlExternally(iUri);
     event.preventDefault();
     event.stopPropagation();
-  }
-  catch (ex) {}
+  } catch (ex) {}
 }
 
 function EnigGetHttpUri(aEvent) {
@@ -667,12 +630,10 @@ function EnigGetHttpUri(aEvent) {
       target instanceof HTMLLinkElement) {
       if (target.hasAttribute("href"))
         href = target.href;
-    }
-    else if (!aDontCheckInputElement && target instanceof HTMLInputElement) {
+    } else if (!aDontCheckInputElement && target instanceof HTMLInputElement) {
       if (target.form && target.form.action)
         href = target.form.action;
-    }
-    else {
+    } else {
       // we may be nested inside of a link node
       var linkNode = aEvent.originalTarget;
       while (linkNode && !(linkNode instanceof HTMLAnchorElement))
@@ -748,7 +709,7 @@ function EnigCleanGuiList(guiList) {
  * @return treecell node
  */
 function createCell(label) {
-  var cell = document.createElement("treecell");
+  var cell = document.createXULElement("treecell");
   cell.setAttribute("label", label);
   return cell;
 }
@@ -795,21 +756,19 @@ function EnigGetKeyDetails(sigListStr) {
         subkeyList.push(aLine);
         if (!gUserId) {
           gUserId = EnigConvertGpgToUnicode(aLine[9]);
-        }
-        else if (uidList !== false) {
+        } else if (uidList !== false) {
           uidList.push(aLine);
         }
         break;
       case "uid":
         if (!gUserId) {
           gUserId = EnigConvertGpgToUnicode(aLine[9]);
-        }
-        else if (uidList !== false) {
+        } else if (uidList !== false) {
           uidList.push(aLine);
         }
         break;
       case "uat":
-        // @TODO document what that means
+        // User Attributes with "1 " in field 9 determine JPEG pictures
         if (aLine[9].search("1 ") === 0) {
           showPhoto = true;
         }
@@ -837,4 +796,4 @@ function EnigGetKeyDetails(sigListStr) {
     subkeyList: subkeyList
   };
   return keyDetails;
-}
+}
\ No newline at end of file
