@@ -1,18 +1,17 @@
-/*global Components: false */
 /*
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at https://mozilla.org/MPL/2.0/.
  */
 
 
 "use strict";
 
-Components.utils.import("resource://enigmail/core.jsm"); /*global EnigmailCore: false*/
-Components.utils.import("resource://enigmail/pipeConsole.jsm"); /*global EnigmailConsole: false */
-Components.utils.import("resource://enigmail/log.jsm"); /*global EnigmailLog: false */
-Components.utils.import("resource://enigmail/data.jsm"); /*global EnigmailData: false */
-Components.utils.import("resource://enigmail/windows.jsm"); /*global EnigmailWindows: false */
+var EnigmailCore = ChromeUtils.import("chrome://enigmail/content/modules/core.jsm").EnigmailCore;
+var EnigmailConsole = ChromeUtils.import("chrome://enigmail/content/modules/pipeConsole.jsm").EnigmailConsole;
+var EnigmailLog = ChromeUtils.import("chrome://enigmail/content/modules/log.jsm").EnigmailLog;
+var EnigmailData = ChromeUtils.import("chrome://enigmail/content/modules/data.jsm").EnigmailData;
+var EnigmailWindows = ChromeUtils.import("chrome://enigmail/content/modules/windows.jsm").EnigmailWindows;
 
 /* global goUpdateCommand: false */
 
@@ -89,8 +88,7 @@ function getSelectionStr() {
     var sel = contentFrame.getSelection();
     return sel.toString();
 
-  }
-  catch (ex) {
+  } catch (ex) {
     return "";
   }
 }
@@ -135,4 +133,4 @@ var CommandController = {
   },
 
   onEvent: function(aEvent) {}
-};
+};
\ No newline at end of file
