@@ -1,23 +1,25 @@
-/*global Components */
 /*
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at https://mozilla.org/MPL/2.0/.
  */
 
-// Uses: chrome://enigmail/content/enigmailCommon.js
+// Uses: chrome://enigmail/content/ui/enigmailCommon.js
 
 "use strict";
 
-
 /* global EnigInitCommon: false, EnigmailTrust: false, EnigGetString: false, EnigmailCore: false, EnigmailLog: false */
 /* global EnigmailKeyRing: false, EnigGetPref: false, EnigGetTrustLabel: false, EnigSetActive: false, EnigAlert: false */
 /* global EnigSetPref: false, EnigConfirm: false, EnigmailPrefs: false, EnigDownloadKeys: false */
 
 // Initialize enigmailCommon
 EnigInitCommon("enigmailKeySelection");
-Components.utils.import("resource://enigmail/funcs.jsm"); /* global EnigmailFuncs: false */
-Components.utils.import("resource://enigmail/key.jsm"); /*global EnigmailKey: false */
+var EnigmailFuncs = ChromeUtils.import("chrome://enigmail/content/modules/funcs.jsm").EnigmailFuncs;
+var EnigmailKey = ChromeUtils.import("chrome://enigmail/content/modules/key.jsm").EnigmailKey;
+var EnigmailSearchCallback = ChromeUtils.import("chrome://enigmail/content/modules/searchCallback.jsm").EnigmailSearchCallback;
+var EnigmailCryptoAPI = ChromeUtils.import("chrome://enigmail/content/modules/cryptoAPI.jsm").EnigmailCryptoAPI;
+var newEnigmailKeyObj = ChromeUtils.import("chrome://enigmail/content/modules/keyObj.jsm").newEnigmailKeyObj;
+
 
 const INPUT = 0;
 const RESULT = 1;
@@ -51,6 +53,7 @@ var gSendEncrypted = true;
 var gSendSigned = true;
 var gAllowExpired = false;
 var gIpcRequest;
+var gTimeoutId = {};
 
 var gEnigRemoveListener = false;
 var gKeysNotFound = [];
@@ -60,16 +63,21 @@ const EMPTY_UID = " -";
 
 function onLoad() {
   EnigmailLog.DEBUG("enigmailKeySelection.js: onLoad\n");
+
   gIpcRequest = null;
   if (window.arguments[INPUT].options.indexOf("private") >= 0) {
     document.getElementById("enigmailKeySelectionDlg").setAttribute("title", EnigGetString("userSel.secretKeySel.title"));
   }
   document.getElementById("enigmailUserIdSelection").addEventListener('click', onClickCallback, true);
+  EnigmailSearchCallback.setup(document.getElementById("filterKey"), gTimeoutId, applyFilter, 200);
+
   let enigmailSvc = EnigmailCore.getService(window);
   if (!enigmailSvc) {
     return false;
   }
   buildList(false);
+
+  return true;
 }
 
 
@@ -87,7 +95,10 @@ function refreshKeys() {
 
 function getKeyList(secretOnly, refresh) {
   EnigmailLog.DEBUG("enigmailMessengerOverlay.js: getKeyList\n");
-  let userList, keyList;
+
+  const cApi = EnigmailCryptoAPI();
+  let userList,
+    keyList;
   try {
     var exitCodeObj = {};
     var statusFlagsObj = {};
@@ -101,8 +112,7 @@ function getKeyList(secretOnly, refresh) {
       userList = EnigmailKeyRing.getAllSecretKeys(window);
       if (!userList) return null;
       keyList = EnigmailFuncs.cloneObj(userList);
-    }
-    else {
+    } else {
       userList = EnigmailKeyRing.getAllKeys(window);
       if (!userList) return null;
 
@@ -111,14 +121,16 @@ function getKeyList(secretOnly, refresh) {
       }
 
       keyList = EnigmailFuncs.cloneObj(userList.keyList);
-      let grpList = EnigmailKeyRing.getGroups();
+
+      let grpList = cApi.getGroups().map(k => {
+        return newEnigmailKeyObj(k);
+      });
 
       for (let i in grpList) {
         keyList.push(grpList[i]);
       }
     }
-  }
-  catch (ex) {
+  } catch (ex) {
     EnigmailLog.writeException("enigmailKeySelection.js: getKeyList", ex);
   }
 
@@ -151,15 +163,13 @@ function sortKeys(a, b) {
   // 4th: sort according to user IDs
   else if (a.userId.toLowerCase() < b.userId.toLowerCase()) {
     r = -1;
-  }
-  else if (a.userId.toLowerCase() > b.userId.toLowerCase()) {
+  } else if (a.userId.toLowerCase() > b.userId.toLowerCase()) {
     r = 1;
   }
   // 5th: sort according to trust level (higher index value in front)
   else if (TRUSTLEVELS_SORTED.indexOf(a.keyTrust) > TRUSTLEVELS_SORTED.indexOf(b.keyTrust)) {
     r = -1;
-  }
-  else {
+  } else {
     r = 1;
   }
   return r;
@@ -172,16 +182,22 @@ function prepareDialog(secretOnly) {
   if (window.arguments[INPUT].dialogHeader) {
     var dialogHeader = document.getElementById("dialogHeader");
     if (dialogHeader) {
-      dialogHeader.setAttribute("label", window.arguments[INPUT].dialogHeader);
-      dialogHeader.removeAttribute("collapsed");
+      dialogHeader.innerHTML = window.arguments[INPUT].dialogHeader;
+      dialogHeader.style.visibility = "visible";
     }
+  } else {
+    let box = document.getElementById("dialogHeaderBox");
+    box.setAttribute("class", "enigmailCaptionboxNoTitle");
+    box.removeChild(box.firstChild);
   }
   var dialogMsgList = document.getElementById("dialogMsgList");
-  if (dialogMsgList) {
+  var dialogMsgListRows = document.getElementById("dialogMsgListRows");
+  if (dialogMsgListRows) {
     // clear the list (otherwise it grows with each loaded missing key)
-    while (dialogMsgList.getRowCount() > 0) {
-      dialogMsgList.removeIndexAt(0);
+    while (dialogMsgListRows.firstChild) {
+      dialogMsgListRows.removeChild(dialogMsgListRows.firstChild);
     }
+
     // fill the list according to the error messages
     if (window.arguments[INPUT].errArray && window.arguments[INPUT].errArray.length > 0) {
       var array = window.arguments[INPUT].errArray;
@@ -190,6 +206,9 @@ function prepareDialog(secretOnly) {
         switch (array[detIdx].msg) {
           case "ProblemNoKey":
             msg = EnigGetString("userSel.problemNoKey");
+            if (window.arguments[INPUT].options.indexOf("nosending") < 0) {
+              document.getElementById("importMissingKeys").removeAttribute("collapsed");
+            }
             break;
           case "ProblemMultipleKeys":
             msg = EnigGetString("userSel.problemMultipleKeys");
@@ -199,19 +218,17 @@ function prepareDialog(secretOnly) {
             msg = "???";
             break;
         }
-        var row = document.createElement('listitem');
-        var cell = document.createElement('listcell');
-        cell.setAttribute('label', array[detIdx].addr + ":");
+        var row = document.createXULElement('row');
+        var cell = document.createXULElement('label');
+        cell.setAttribute('value', array[detIdx].addr + ":");
         row.appendChild(cell);
-        cell = document.createElement('listcell');
-        cell.setAttribute('label', msg);
+        cell = document.createXULElement('label');
+        cell.setAttribute('value', msg);
         row.appendChild(cell);
-        dialogMsgList.appendChild(row);
+        dialogMsgListRows.appendChild(row);
       }
-      dialogMsgList.setAttribute("rows", (array.length < 3 ? array.length : 3));
       dialogMsgList.removeAttribute("collapsed");
-    }
-    else {
+    } else {
       dialogMsgList.setAttribute("collapsed", "true");
     }
   }
@@ -246,9 +263,7 @@ function prepareDialog(secretOnly) {
     document.getElementById("dialogHeadline").setAttribute("collapsed", "true");
     document.getElementById("enigmailUserSelSendSigned").setAttribute("collapsed", "true");
     document.getElementById("enigmailUserSelSendEncrypted").setAttribute("collapsed", "true");
-    document.getElementById("importMissingKeys").setAttribute("collapsed", "true");
-  }
-  else if (window.arguments[INPUT].options.indexOf("noforcedisp") >= 0) {
+  } else if (window.arguments[INPUT].options.indexOf("noforcedisp") >= 0) {
     document.getElementById("displayNoLonger").removeAttribute("collapsed");
   }
 
@@ -294,8 +309,7 @@ function buildList(refresh) {
   var uidNotValid;
   if (gAlwaysTrust) {
     uidNotValid = "";
-  }
-  else {
+  } else {
     uidNotValid = "o-qn";
   }
 
@@ -304,8 +318,7 @@ function buildList(refresh) {
 
   try {
     prepareDialog(secretOnly);
-  }
-  catch (ex) {
+  } catch (ex) {
     EnigmailLog.DEBUG("EXCEPTION: " + ex.toString() + "\n");
   }
 
@@ -317,8 +330,7 @@ function buildList(refresh) {
     if (typeof(window.arguments[INPUT].toKeys) == "string") {
       toKeys = window.arguments[INPUT].toKeys;
     }
-  }
-  catch (ex) {}
+  } catch (ex) {}
 
   var invalidAddr = "";
   try {
@@ -330,8 +342,7 @@ function buildList(refresh) {
     if (typeof(window.arguments[INPUT].invalidAddr) == "string") {
       invalidAddr = " " + window.arguments[INPUT].invalidAddr + " ";
     }
-  }
-  catch (ex) {}
+  } catch (ex) {}
 
   // sort out PGP keys in toAddr
   var toAddrList = getToAddrList();
@@ -348,7 +359,8 @@ function buildList(refresh) {
   var now = d.valueOf() / 1000;
   var aValidUsers = [];
 
-  var mailAddr, escapedMailAddr;
+  var mailAddr,
+    escapedMailAddr;
   var s1;
   // Replace any non-text character c with \\c
   var escapeRegExp = new RegExp("([^a-zA-Z0-9])", "g");
@@ -416,15 +428,13 @@ function buildList(refresh) {
             if (invalidAddr.indexOf(" " + mailAddr + " ") < 0) {
               aValidUsers.push(mailAddr);
               aUserList[i].activeState = (toAddr.search(s1) >= 0 ? 1 : 0);
-            }
-            else {
+            } else {
               // mail address found as invalid address: marks that to sort them to the beginning
               aUserList[i].uidMatchInvalid = true;
               aUserList[i].uidValid = false;
               aUserList[i].activeState = 0;
             }
-          }
-          else {
+          } else {
             aUserList[i].uidValid = false;
             aUserList[i].activeState = 0;
           }
@@ -439,8 +449,7 @@ function buildList(refresh) {
             }
           }
         }
-      }
-      else {
+      } else {
         // special handling for gpg groups
         mailAddr = stripEmailFromKey(aUserList[i].userId);
         aValidUsers.push(mailAddr);
@@ -448,8 +457,7 @@ function buildList(refresh) {
         aUserList[i].uidValid = true;
         if (toKeys.length > 0) {
           aUserList[i].activeState = (toKeys.indexOf("GROUP:" + aUserList[i].keyId + ",") >= 0 ? 1 : 0);
-        }
-        else
+        } else
           aUserList[i].activeState = 0;
       }
 
@@ -475,8 +483,7 @@ function buildList(refresh) {
         }
       }
     }
-  }
-  catch (ex) {
+  } catch (ex) {
     EnigmailLog.ERROR("enigmailKeySelection.js: ERROR in buildList: " + ex.toString() + "\n" + ex.stack + "\n");
   }
 
@@ -503,12 +510,11 @@ function buildTreeView(aUserList, hideExpired, secretOnly) {
       // do not show if expired keys are hidden
       if (secretOnly) {
         treeItem = enigUserSelCreateRow(aUserList[i], aUserList[i].activeState, aUserList[i].userId, aUserList[i].keyId, aUserList[i].created, "", true);
-      }
-      else {
+      } else {
         treeItem = enigUserSelCreateRow(aUserList[i], aUserList[i].activeState, aUserList[i].userId, aUserList[i].keyId, aUserList[i].expiry, aUserList[i].keyTrust, aUserList[i].uidValid);
       }
       if (aUserList[i].hasSubUserIds()) {
-        var subChildren = document.createElement("treechildren");
+        var subChildren = document.createXULElement("treechildren");
         for (let user = 1; user < aUserList[i].userIds.length; user++) {
           if (KEY_NOT_VALID.indexOf(aUserList[i].userIds[user].keyTrust) < 0) {
             var subItem = enigUserSelCreateRow(aUserList[i], -1, aUserList[i].userIds[user].userId, "", "", aUserList[i].userIds[user].keyTrust, true);
@@ -535,7 +541,8 @@ function buildNotFoundKeys(aUserList, aValidUsers, toAddrList, toKeys) {
   EnigmailLog.DEBUG("enigmailKeySelection.js: buildNotFoundKeys\n");
 
   gKeysNotFound = [];
-  let i, j;
+  let i,
+    j;
   for (i = 0; i < toAddrList.length; i++) {
     if (toAddrList[i].length > 0) {
       let found = false;
@@ -575,11 +582,11 @@ function buildNotFoundKeys(aUserList, aValidUsers, toAddrList, toKeys) {
 
 // create a (sub) row for the user tree
 function enigUserSelCreateRow(userObj, activeState, userId, keyValue, dateField, uidValidityStatus, uidValid) {
-  var selectCol = document.createElement("treecell");
+  var selectCol = document.createXULElement("treecell");
   selectCol.setAttribute("id", "indicator");
-  var uidValidityCol = document.createElement("treecell");
-  var expCol = document.createElement("treecell");
-  var userCol = document.createElement("treecell");
+  var uidValidityCol = document.createXULElement("treecell");
+  var expCol = document.createXULElement("treecell");
+  var userCol = document.createXULElement("treecell");
 
   userCol.setAttribute("id", "name");
   expCol.setAttribute("id", "expiry");
@@ -588,11 +595,10 @@ function enigUserSelCreateRow(userObj, activeState, userId, keyValue, dateField,
   userCol.setAttribute("label", userId);
   expCol.setAttribute("label", dateField);
 
-  var keyCol = document.createElement("treecell");
+  var keyCol = document.createXULElement("treecell");
   if (userObj.keyTrust != KEY_IS_GROUP) {
-    keyCol.setAttribute("label", keyValue.substring(8, 16));
-  }
-  else {
+    keyCol.setAttribute("label", "0x" + keyValue);
+  } else {
     keyCol.setAttribute("label", EnigGetString("keyTrust.group"));
   }
   keyCol.setAttribute("id", "keyid");
@@ -620,8 +626,7 @@ function enigUserSelCreateRow(userObj, activeState, userId, keyValue, dateField,
     if (!gAllowExpired && activeState >= 0) {
       activeState = 2;
     }
-  }
-  else if (!gAlwaysTrust) {
+  } else if (!gAlwaysTrust) {
     if (("mfu".indexOf(userObj.keyTrust.charAt(0)) < 0) ||
       (uidValidityStatus.length > 0) &&
       ("o-qn".indexOf(uidValidityStatus.charAt(0)) >= 0)) {
@@ -635,17 +640,16 @@ function enigUserSelCreateRow(userObj, activeState, userId, keyValue, dateField,
 
   EnigSetActive(selectCol, activeState);
   uidValidityCol.setAttribute("label", validity);
-  var userRow = document.createElement("treerow");
+  var userRow = document.createXULElement("treerow");
   userRow.appendChild(selectCol);
   userRow.appendChild(userCol);
   userRow.appendChild(uidValidityCol);
   userRow.appendChild(expCol);
   userRow.appendChild(keyCol);
-  var treeItem = document.createElement("treeitem");
+  var treeItem = document.createXULElement("treeitem");
   if (userObj.keyTrust == KEY_IS_GROUP) {
     treeItem.setAttribute("id", "GROUP:" + userObj.keyId);
-  }
-  else {
+  } else {
     treeItem.setAttribute("id", "0x" + userObj.keyId);
     if (userObj.fpr.length > 0) {
       treeItem.setAttribute("fpr", "0x" + userObj.fpr);
@@ -673,13 +677,11 @@ function onAccept() {
       item = gUserList.view.getItemAtIndex(gUserList.currentIndex);
       if (item.getAttribute("fpr")) {
         resultObj.userList.push(item.getAttribute("fpr"));
-      }
-      else {
+      } else {
         resultObj.userList.push(item.getAttribute("id"));
       }
     }
-  }
-  else {
+  } else {
     item = treeChildren.firstChild;
     while (item) {
       var aRows = item.getElementsByAttribute("id", "indicator");
@@ -688,8 +690,7 @@ function onAccept() {
         if (elem.getAttribute("active") == "1") {
           if (item.getAttribute("fpr")) {
             resultObj.userList.push(item.getAttribute("fpr"));
-          }
-          else {
+          } else {
             resultObj.userList.push(item.getAttribute("id"));
           }
         }
@@ -724,8 +725,7 @@ function getToAddrList() {
   var toAddrList;
   try {
     toAddrList = EnigmailFuncs.stripEmail(window.arguments[INPUT].toAddr).split(/[ ,]+/);
-  }
-  catch (ex) {
+  } catch (ex) {
     toAddrList = [];
   }
   return toAddrList;
@@ -741,45 +741,45 @@ function userSelCallback(event) {
   if (!gSendEncrypted)
     return;
 
-  var row = {};
-  var col = {};
-  var elt = {};
-  var Tree;
+  let Tree;
+  let row;
+  let col;
   if (event.type == "keypress") {
     // key event
     if (event.charCode == 32) {
       Tree = event.target;
       if (Tree.view.selection.count > 0) {
-        row.value = Tree.view.selection.currentIndex;
+        row = Tree.view.selection.currentIndex;
       }
-    }
-    else {
+    } else {
       return;
     }
-  }
-  else if (event.type == "click") {
+  } else if (event.type == "click") {
     // Mouse event
     Tree = document.getElementById("enigmailUserIdSelection");
-    Tree.treeBoxObject.getCellAt(event.clientX, event.clientY, row, col, elt);
 
-    if (!col.value) // not clicked on a valid column (e.g. scrollbar)
+    let treeInfo = Tree.getCellAt(event.clientX, event.clientY);
+    row = treeInfo.row;
+    col = treeInfo.col;
+
+    if (!treeInfo.col) // not clicked on a valid column (e.g. scrollbar)
       return;
 
     if (event.detail > 2) return;
 
-    if ((event.detail == 1) && (col.value.id != "selectionCol"))
+    if ((event.detail == 1) && (col.id != "selectionCol"))
       return; // single clicks are only relevant for the selection column
 
-    if ((event.detail == 2) && ("selectionCol,enigUserNameCol,uidValidityCol,expCol,keyCol".indexOf(col.value.id) < 0))
+    if ((event.detail == 2) && ("selectionCol,enigUserNameCol,uidValidityCol,expCol,keyCol".indexOf(col.id) < 0))
       return;
 
     event.stopPropagation();
 
   }
 
-  if (row.value == -1)
+  if (row == -1)
     return;
-  var treeItem = Tree.contentView.getItemAtIndex(row.value);
+  var treeItem = Tree.view.getItemAtIndex(row);
   Tree.currentItem = treeItem;
   var aRows = treeItem.getElementsByAttribute("id", "indicator");
 
@@ -794,8 +794,7 @@ function userSelCallback(event) {
     var elem = aRows[0];
     if (elem.getAttribute("active") == "1") {
       EnigSetActive(elem, 0);
-    }
-    else if (elem.getAttribute("active") == "0") {
+    } else if (elem.getAttribute("active") == "0") {
       EnigSetActive(elem, 1);
     }
   }
@@ -817,8 +816,7 @@ function displayNoLonger() {
   var dispMsg = document.getElementById("displayNoLonger");
   if (gSendEncrypted) {
     dispMsg.setAttribute("disabled", "true");
-  }
-  else {
+  } else {
     dispMsg.removeAttribute("disabled");
   }
 }
@@ -833,8 +831,7 @@ function disableList() {
     if (node.localName == "treecol") {
       if (gSendEncrypted) {
         node.removeAttribute("properties");
-      }
-      else {
+      } else {
         node.setAttribute("properties", "enigDontEncrypt");
       }
     }
@@ -877,10 +874,12 @@ function searchMissingKeys() {
     window.close();
     return true;
   }
+
+  return null;
 }
 
 
-function onSearchInput() {
+function applyFilter() {
   let searchInput = document.getElementById("filterKey");
   let searchValue = searchInput.value.toLowerCase();
   let userTreeList = document.getElementById("enigmailUserIdSelection");
@@ -891,8 +890,7 @@ function onSearchInput() {
     for (let item = treeChildren.firstChild; item; item = item.nextSibling) {
       item.setAttribute("hidden", false);
     }
-  }
-  else {
+  } else {
     // hide items that are
     // - not active
     // - and do not match the search string in all names/emails or key
@@ -937,13 +935,21 @@ function onSearchInput() {
 function stripEmailFromKey(uid) {
   try {
     return EnigmailFuncs.stripEmail(uid).toLowerCase();
-  }
-  catch (ex) {
+  } catch (ex) {
     // remove quotes
-    return EnigmailFuncs.stripEmail(uid.replace(/\"/g, "")).toLowerCase();
-  }
-  finally {
+    return EnigmailFuncs.stripEmail(uid.replace(/"/g, "")).toLowerCase();
+  } finally {
     // search for last ocurrence of < >
     return uid.replace(/(.*)(<)([^<> ]+)(>[^<>]*)$/, "$3").toLowerCase(); // eslint-disable-line no-unsafe-finally
   }
 }
+
+document.addEventListener("dialogaccept", function(event) {
+  if (!onAccept())
+    event.preventDefault(); // Prevent the dialog closing.
+});
+
+
+document.addEventListener("dialogextra1", function(event) {
+  newRecipientRule();
+});
\ No newline at end of file
