@@ -1,11 +1,10 @@
-/*global Components: false */
 /*
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at https://mozilla.org/MPL/2.0/.
  */
 
-// Uses: chrome://enigmail/content/enigmailCommon.js
+// Uses: chrome://enigmail/content/ui/enigmailCommon.js
 
 "use strict";
 
@@ -35,8 +34,6 @@ var gGeneratedKey = null;
 var gUsedId;
 
 const KEYGEN_CANCELLED = "cancelled";
-const KEYTYPE_DSA = 1;
-const KEYTYPE_RSA = 2;
 
 function enigmailKeygenLoad() {
   EnigmailLog.DEBUG("enigmailKeygen.js: Load\n");
@@ -52,6 +49,14 @@ function enigmailKeygenLoad() {
     noPassphrase.setAttribute("collapsed", "true");
   }
 
+  if (EnigmailGpg.getGpgFeature("supports-ecc-keys")) {
+    let eccElem = document.getElementById("keyType_ecc");
+    eccElem.removeAttribute("hidden");
+    updateKeySizeSel(eccElem);
+    document.getElementById("keyType").selectedItem = eccElem;
+  }
+
+
   if (gUserIdentityListPopup) {
     fillIdentityListPopup();
   }
@@ -79,6 +84,14 @@ function enigmailKeygenLoad() {
   }
 }
 
+function updateKeySizeSel(selectedObj) {
+  if (selectedObj.id === "keyType_ecc") {
+    document.getElementById("keySize").setAttribute("disabled", "true");
+  } else {
+    document.getElementById("keySize").removeAttribute("disabled");
+  }
+}
+
 function enigmailOnClose() {
   var closeWin = true;
   if (gKeygenRequest) {
@@ -133,7 +146,7 @@ function enigmailKeygenTerminate(exitCode) {
     if (gUseForSigning.checked) {
       curId.setBoolAttribute("enablePgp", true);
       curId.setIntAttribute("pgpKeyMode", 1);
-      curId.setCharAttribute("pgpkeyId", "0x" + gGeneratedKey.substr(-8, 8));
+      curId.setCharAttribute("pgpkeyId", "0x" + gGeneratedKey);
 
       enigmailKeygenUpdate(false, true);
 
@@ -143,11 +156,9 @@ function enigmailKeygenTerminate(exitCode) {
 
       if (EnigConfirm(EnigGetString("keygenComplete", curId.email) + "\n\n" + EnigGetString("revokeCertRecommended"), EnigGetString("keyMan.button.generateCert"))) {
         EnigCreateRevokeCert(gGeneratedKey, curId.email, closeAndReset);
-      }
-      else
+      } else
         closeAndReset();
-    }
-    else {
+    } else {
       if (EnigConfirm(EnigGetString("genCompleteNoSign") + "\n\n" + EnigGetString("revokeCertRecommended"), EnigGetString("keyMan.button.generateCert"))) {
         EnigCreateRevokeCert(gGeneratedKey, curId.email, closeAndReset);
         genAndSaveRevCert(gGeneratedKey, curId.email).then(
@@ -158,12 +169,10 @@ function enigmailKeygenTerminate(exitCode) {
             // do nothing
           }
         );
-      }
-      else
+      } else
         closeAndReset();
     }
-  }
-  else {
+  } else {
     EnigAlert(EnigGetString("keyGenFailed"));
     window.close();
   }
@@ -181,9 +190,8 @@ function genAndSaveRevCert(keyId, uid) {
   return new Promise(
     function(resolve, reject) {
 
-      let keyIdShort = "0x" + keyId.substr(-16, 16);
       let keyFile = EnigmailApp.getProfileDirectory();
-      keyFile.append(keyIdShort + "_rev.asc");
+      keyFile.append("0x" + keyId + "_rev.asc");
 
       // create a revokation cert in the TB profile directoy
       EnigmailKeyEditor.genRevokeCert(window, "0x" + keyId, keyFile, "1", "",
@@ -203,8 +211,8 @@ function genAndSaveRevCert(keyId, uid) {
  */
 function saveRevCert(inputKeyFile, keyId, uid, resolve, reject) {
 
-  let defaultFileName = uid.replace(/[\\\/<\>]/g, "");
-  defaultFileName += " (0x" + keyId.substr(-8, 8) + ") rev.asc";
+  let defaultFileName = uid.replace(/[\\/<>]/g, "");
+  defaultFileName += " (0x" + keyId + ") rev.asc";
 
   let outFile = EnigFilePicker(EnigGetString("saveRevokeCertAs"),
     "", true, "*.asc",
@@ -213,9 +221,8 @@ function saveRevCert(inputKeyFile, keyId, uid, resolve, reject) {
   if (outFile) {
     try {
       inputKeyFile.copyToFollowingLinks(outFile.parent, outFile.leafName);
-      EnigAlert(EnigGetString("revokeCertOK"));
-    }
-    catch (ex) {
+      EnigmailDialog.info(window, EnigGetString("revokeCertOK"));
+    } catch (ex) {
       EnigAlert(EnigGetString("revokeCertFailed"));
       reject(2);
     }
@@ -261,10 +268,6 @@ function enigmailCheckPassphrase() {
     return null;
   }
 
-  if (passphrase.length < 8) {
-    EnigAlert(EnigGetString("passphrase.min8keys"));
-    return null;
-  }
   return passphrase;
 }
 
@@ -277,7 +280,7 @@ function enigmailKeygenStart() {
   if (gKeygenRequest) {
     let req = gKeygenRequest.QueryInterface(Components.interfaces.nsIRequest);
     if (req.isPending()) {
-      EnigAlert(EnigGetString("genGoing"));
+      EnigmailDialog.info(window, EnigGetString("genGoing"));
       return;
     }
   }
@@ -299,16 +302,15 @@ function enigmailKeygenStart() {
 
     if (!noPassphraseElement.checked) {
       if (passphraseElement.value.trim() === "") {
-        EnigAlert(EnigGetString("passCheckBox"));
+        EnigmailDialog.info(window, EnigGetString("passCheckBox"));
         return;
       }
 
       passphrase = enigmailCheckPassphrase();
-      if (!passphrase) return;
+      if (passphrase === null) return;
     }
 
-  }
-  else {
+  } else {
     passphrase = "";
   }
 
@@ -320,21 +322,16 @@ function enigmailKeygenStart() {
   if (!noExpiry.checked) {
     expiryTime = Number(expireInput.value) * Number(timeScale.value);
     if (expiryTime > 36500) {
-      EnigAlert(EnigGetString("expiryTooLong"));
+      EnigmailDialog.info(window, EnigGetString("expiryTooLong"));
       return;
     }
     if (expiryTime <= 0) {
-      EnigAlert(EnigGetString("expiryTooShort"));
+      EnigmailDialog.info(window, EnigGetString("expiryTooShort"));
       return;
     }
   }
   var keySize = Number(document.getElementById("keySize").value);
-  var keyType = Number(document.getElementById("keyType").value);
-
-  if ((keyType == KEYTYPE_DSA) && (keySize > 3072)) {
-    EnigAlert(EnigGetString("dsaSizeLimit"));
-    keySize = 3072;
-  }
+  var keyType = document.getElementById("keyType").value;
 
   var curId = getCurrentIdentity();
   gUsedId = curId;
@@ -343,7 +340,7 @@ function enigmailKeygenStart() {
   var userEmail = curId.email;
 
   if (!userName) {
-    EnigAlert(EnigGetString("keygen.missingUserName"));
+    EnigmailDialog.info(window, EnigGetString("keygen.missingUserName"));
     return;
   }
 
@@ -393,8 +390,7 @@ function enigmailKeygenStart() {
       keyType,
       EnigmailData.convertFromUnicode(passphrase),
       listener);
-  }
-  catch (ex) {
+  } catch (ex) {
     EnigmailLog.DEBUG("enigmailKeygen.js: generateKey() failed with " + ex.toString() + "\n" + ex.stack + "\n");
   }
 
@@ -417,8 +413,7 @@ function enigmailKeygenCancel() {
   if (gKeygenRequest) {
     closeWin = EnigConfirm(EnigGetString("keyAbort"), EnigGetString("keyMan.button.generateKeyAbort"), EnigGetString("keyMan.button.generateKeyContinue"));
     if (closeWin) abortKeyGeneration();
-  }
-  else {
+  } else {
     closeWin = true;
   }
 
@@ -471,17 +466,14 @@ function fillIdentityListPopup() {
     // Gecko >= 20
     if (defIdentities.length >= 1) {
       defIdentity = defIdentities.queryElementAt(0, Components.interfaces.nsIMsgIdentity);
-    }
-    else {
+    } else {
       defIdentity = identities[0];
     }
-  }
-  catch (ex) {
+  } catch (ex) {
     // Gecko < 20
     if (defIdentities.Count() >= 1) {
       defIdentity = defIdentities.QueryElementAt(0, Components.interfaces.nsIMsgIdentity);
-    }
-    else {
+    } else {
       defIdentity = identities[0];
     }
   }
@@ -503,8 +495,7 @@ function fillIdentityListPopup() {
       if (serverSupports.length > 0) {
         inServer = serverSupports.queryElementAt(0, Components.interfaces.nsIMsgIncomingServer);
       }
-    }
-    catch (ex) {
+    } catch (ex) {
       // Gecko < 20
       serverSupports = gAccountManager.GetServersForIdentity(identity);
       if (serverSupports.GetElementAt(0)) {
@@ -518,7 +509,7 @@ function fillIdentityListPopup() {
       EnigmailLog.DEBUG("enigmailKeygen.js: accountName=" + accountName + "\n");
       EnigmailLog.DEBUG("enigmailKeygen.js: email=" + identity.email + "\n");
 
-      var item = document.createElement('menuitem');
+      var item = document.createXULElement('menuitem');
       //      item.setAttribute('label', identity.identityName);
       item.setAttribute('label', identity.identityName + accountName);
       item.setAttribute('class', 'identity-popup-item');
@@ -538,4 +529,4 @@ function fillIdentityListPopup() {
     }
   }
 
-}
+}
\ No newline at end of file
