@@ -1,28 +1,29 @@
 /*
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at https://mozilla.org/MPL/2.0/.
  */
 
-// Uses: chrome://enigmail/content/enigmailCommon.js
+// Uses: chrome://enigmail/content/ui/enigmailCommon.js
 
-/* global Components */
-/* global EnigInitCommon, EnigGetString, GetEnigmailSvc, EnigAlert, EnigConfirm */
+/* global EnigInitCommon, EnigGetString, GetEnigmailSvc, EnigAlert, EnigConfirm, EnigHelpWindow */
 
 "use strict";
 
 // Initialize enigmailCommon
 EnigInitCommon("enigmailRulesEditor");
 
-const Cu = Components.utils;
-Cu.import("resource://enigmail/rules.jsm"); /*global EnigmailRules: false */
-Cu.import("resource://enigmail/log.jsm"); /*global EnigmailLog: false */
+var EnigmailRules = ChromeUtils.import("chrome://enigmail/content/modules/rules.jsm").EnigmailRules;
+var EnigmailLog = ChromeUtils.import("chrome://enigmail/content/modules/log.jsm").EnigmailLog;
+var EnigmailSearchCallback = ChromeUtils.import("chrome://enigmail/content/modules/searchCallback.jsm").EnigmailSearchCallback;
 
 const INPUT = 0;
 const RESULT = 1;
 
 var gSearchInput = null;
 var gNumRows = null;
+var gAutocryptRules = [];
+var gTimeoutId = {};
 
 function enigmailDlgOnLoad() {
   var enigmailSvc = GetEnigmailSvc();
@@ -42,7 +43,6 @@ function enigmailDlgOnLoad() {
     var node = rulesList.firstChild.firstChild;
     while (node) {
       if (node.tagName == "pgpRule") {
-        //try {
         var userObj = {
           email: node.getAttribute("email"),
           keyId: node.getAttribute("keyId"),
@@ -55,18 +55,20 @@ function enigmailDlgOnLoad() {
           userObj.negate = node.getAttribute("negateRule");
         }
 
-        var treeItem = document.createElement("treeitem");
-        createRow(treeItem, userObj);
-        treeChildren.appendChild(treeItem);
-        //}
-        //catch (ex) {}
+        if (userObj.email.search(/^\{autocrypt:\/\/.{1,200}\}$/) === 0) {
+          gAutocryptRules.push(userObj);
+        } else {
+          var treeItem = document.createXULElement("treeitem");
+          createRow(treeItem, userObj);
+          treeChildren.appendChild(treeItem);
+        }
       }
       node = node.nextSibling;
     }
   }
   var rulesTree = document.getElementById("rulesTree");
   gSearchInput = document.getElementById("filterEmail");
-
+  EnigmailSearchCallback.setup(gSearchInput, gTimeoutId, applyFilter, 200);
 }
 
 function enigmailDlgOnAccept() {
@@ -74,11 +76,11 @@ function enigmailDlgOnAccept() {
   var enigmailSvc = GetEnigmailSvc();
   if (!enigmailSvc)
     return false;
-  enigmailSvc.clearRules();
+  EnigmailRules.clearRules();
 
   var node = getFirstNode();
   while (node) {
-    enigmailSvc.addRule(true,
+    EnigmailRules.addRule(true,
       node.getAttribute("email"),
       node.getAttribute("keyId"),
       node.getAttribute("sign"),
@@ -88,13 +90,24 @@ function enigmailDlgOnAccept() {
     );
     node = node.nextSibling;
   }
-  enigmailSvc.saveRulesFile();
+
+  for (let i in gAutocryptRules) {
+    EnigmailRules.addRule(true,
+      gAutocryptRules[i].email,
+      gAutocryptRules[i].keyId,
+      gAutocryptRules[i].sign,
+      gAutocryptRules[i].encrypt,
+      gAutocryptRules[i].pgpMime,
+      "0"
+    );
+  }
+  EnigmailRules.saveRulesFile();
 
   return true;
 }
 
 function createCol(value, label, treeItem, translate) {
-  var column = document.createElement("treecell");
+  var column = document.createXULElement("treecell");
   column.setAttribute("id", value);
   treeItem.setAttribute(value, label);
   switch (value) {
@@ -121,8 +134,7 @@ function createCol(value, label, treeItem, translate) {
     case "negateRule":
       if (Number(label) == 1) {
         label = EnigGetString("negateRule");
-      }
-      else {
+      } else {
         label = "";
       }
   }
@@ -137,7 +149,7 @@ function createRow(treeItem, userObj) {
   var sign = createCol("sign", userObj.sign, treeItem);
   var encrypt = createCol("encrypt", userObj.encrypt, treeItem);
   var pgpMime = createCol("pgpMime", userObj.pgpMime, treeItem);
-  var treeRow = document.createElement("treerow");
+  var treeRow = document.createXULElement("treerow");
   treeRow.appendChild(negate);
   treeRow.appendChild(email);
   treeRow.appendChild(keyId);
@@ -146,10 +158,10 @@ function createRow(treeItem, userObj) {
   treeRow.appendChild(pgpMime);
   treeRow.setAttribute("rowId", ++gNumRows);
 
+
   if (treeItem.firstChild) {
     treeItem.replaceChild(treeRow, treeItem.firstChild);
-  }
-  else {
+  } else {
     treeItem.appendChild(treeRow);
   }
 }
@@ -160,7 +172,7 @@ function getFirstNode() {
 
 function getCurrentNode() {
   var rulesTree = document.getElementById("rulesTree");
-  return rulesTree.contentView.getItemAtIndex(rulesTree.currentIndex);
+  return rulesTree.view.getItemAtIndex(rulesTree.currentIndex);
 }
 
 
@@ -178,7 +190,7 @@ function enigDoEdit() {
     inputObj.pgpmime = Number(node.getAttribute("pgpMime"));
     inputObj.negate = Number(node.getAttribute("negateRule"));
 
-    window.openDialog("chrome://enigmail/content/enigmailSingleRcptSettings.xul", "", "dialog,modal,centerscreen,resizable", inputObj, resultObj);
+    window.openDialog("chrome://enigmail/content/ui/enigmailSingleRcptSettings.xul", "", "dialog,modal,centerscreen,resizable", inputObj, resultObj);
     if (resultObj.cancelled === false) {
       createRow(node, resultObj);
     }
@@ -192,15 +204,14 @@ function enigDoAdd() {
   inputObj.toAddress = "{}";
   inputObj.command = "add";
 
-  window.openDialog("chrome://enigmail/content/enigmailSingleRcptSettings.xul", "", "dialog,modal,centerscreen,resizable", inputObj, resultObj);
+  window.openDialog("chrome://enigmail/content/ui/enigmailSingleRcptSettings.xul", "", "dialog,modal,centerscreen,resizable", inputObj, resultObj);
   if (resultObj.cancelled === false) {
-    var treeItem = document.createElement("treeitem");
+    var treeItem = document.createXULElement("treeitem");
     createRow(treeItem, resultObj);
     var treeChildren = document.getElementById("rulesTreeChildren");
     if (treeChildren.firstChild) {
       treeChildren.insertBefore(treeItem, treeChildren.firstChild);
-    }
-    else {
+    } else {
       treeChildren.appendChild(treeItem);
     }
   }
@@ -255,8 +266,7 @@ function enigDoSearch() {
   while (node) {
     if (node.getAttribute("email").toLowerCase().indexOf(searchTxt) < 0) {
       node.hidden = true;
-    }
-    else {
+    } else {
       node.hidden = false;
     }
     node = node.nextSibling;
@@ -272,7 +282,7 @@ function enigDoResetFilter() {
   }
 }
 
-function onSearchInput() {
+function applyFilter() {
   if (gSearchInput.value === "") {
     enigDoResetFilter();
     return;
@@ -280,3 +290,12 @@ function onSearchInput() {
 
   enigDoSearch();
 }
+
+document.addEventListener("dialogaccept", function(event) {
+  if (!enigmailDlgOnAccept())
+    event.preventDefault(); // Prevent the dialog closing.
+});
+
+document.addEventListener("dialoghelp", function(event) {
+  EnigHelpWindow('rulesEditor');
+});
\ No newline at end of file
