@@ -1,21 +1,18 @@
 /*
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at https://mozilla.org/MPL/2.0/.
  */
 
-/* global Components: false */
-/* global EnigmailKeyEditor: false, EnigmailLog: false, EnigmailLocale: false, EnigmailDialog: false */
-
 "use strict";
 
-Components.utils.import("resource://enigmail/core.jsm"); /*global EnigmailCore: false */
-Components.utils.import("resource://enigmail/keyEditor.jsm");
-Components.utils.import("resource://enigmail/log.jsm");
-Components.utils.import("resource://enigmail/locale.jsm");
-Components.utils.import("resource://enigmail/dialog.jsm");
-Components.utils.import("resource://enigmail/keyRing.jsm"); /*global EnigmailKeyRing: false */
-Components.utils.import("resource://enigmail/trust.jsm"); /*global EnigmailTrust: false */
+var EnigmailCore = ChromeUtils.import("chrome://enigmail/content/modules/core.jsm").EnigmailCore;
+var EnigmailKeyEditor = ChromeUtils.import("chrome://enigmail/content/modules/keyEditor.jsm").EnigmailKeyEditor;
+var EnigmailLog = ChromeUtils.import("chrome://enigmail/content/modules/log.jsm").EnigmailLog;
+var EnigmailLocale = ChromeUtils.import("chrome://enigmail/content/modules/locale.jsm").EnigmailLocale;
+var EnigmailDialog = ChromeUtils.import("chrome://enigmail/content/modules/dialog.jsm").EnigmailDialog;
+var EnigmailKeyRing = ChromeUtils.import("chrome://enigmail/content/modules/keyRing.jsm").EnigmailKeyRing;
+var EnigmailTrust = ChromeUtils.import("chrome://enigmail/content/modules/trust.jsm").EnigmailTrust;
 
 var gExportableSignatureList = null;
 var gLocalSignatureList = null;
@@ -35,14 +32,14 @@ function onLoad() {
   }
   var keys = EnigmailKeyRing.getAllSecretKeys(true);
   if (keys.length === 0) {
-    EnigmailDialog.alert(null, EnigmailLocale.getString("noTrustedOwnKeys"));
+    EnigmailDialog.info(null, EnigmailLocale.getString("noTrustedOwnKeys"));
     window.close();
     return;
   }
   var menulist = document.getElementById("signWithKey");
 
   for (key of keys) {
-    menulist.appendItem(key.userId + " - 0x" + key.keyId.substr(-8, 8), key.keyId);
+    menulist.appendItem(key.userId + " - 0x" + key.keyId, key.keyId);
   }
   if (menulist.selectedIndex == -1) {
     menulist.selectedIndex = 0;
@@ -77,16 +74,14 @@ function onLoad() {
           if (sigType === "x") {
             if (gExportableSignatureList[signer] === undefined) {
               gExportableSignatureList[signer] = 1;
-            }
-            else {
+            } else {
               gExportableSignatureList[signer] += 1;
             }
           }
           if (sigType === "l") {
             if (gLocalSignatureList[signer] === undefined) {
               gLocalSignatureList[signer] = 1;
-            }
-            else {
+            } else {
               gLocalSignatureList[signer] += 1;
             }
           }
@@ -95,7 +90,7 @@ function onLoad() {
     }
     enigKeySelCb();
 
-    var keyDesc = keyObj.userId + " - 0x" + keyObj.keyId.substr(-8, 8);
+    var keyDesc = keyObj.userId + " - 0x" + keyObj.keyId;
     document.getElementById("keyId").value = keyDesc;
     if (keyObj.fpr && keyObj.fpr.length > 0) {
       document.getElementById("fingerprint").value = keyObj.fprFormatted;
@@ -108,7 +103,7 @@ function onLoad() {
       for (let j = 1; j < keyObj.userIds.length; j++) {
         if (keyObj.userIds[j].type === "uid" && (!EnigmailTrust.isInvalid(keyObj.userIds[j].keyTrust))) {
           ++nUid;
-          let uidLbl = document.createElement("label");
+          let uidLbl = document.createXULElement("label");
           uidLbl.setAttribute("value", keyObj.userIds[j].userId);
           sUid.appendChild(uidLbl);
         }
@@ -119,8 +114,7 @@ function onLoad() {
       }
     }
 
-  }
-  catch (ex) {}
+  } catch (ex) {}
 }
 
 function onAccept() {
@@ -142,8 +136,7 @@ function onAccept() {
     function(exitCode, errorMsg) {
       if (exitCode !== 0) {
         EnigmailDialog.alert(window, EnigmailLocale.getString("signKeyFailed") + "\n\n" + errorMsg);
-      }
-      else {
+      } else {
         window.arguments[1].refresh = true;
       }
       window.close();
@@ -155,7 +148,6 @@ function onAccept() {
 
 function enigKeySelCb() {
   var keyToBeSigned = window.arguments[0].keyId;
-  var keyToBeSigned32 = keyToBeSigned.substr(-8, 8);
   var signWithKey = document.getElementById("signWithKey");
   var signWithKeyId = signWithKey.selectedItem.value;
   var alreadySigned = document.getElementById("alreadySigned");
@@ -165,40 +157,40 @@ function enigKeySelCb() {
 
   if (doLocalSig.checked) {
     signatureCount = gLocalSignatureList[signWithKeyId];
-  }
-  else {
+  } else {
     signatureCount = gExportableSignatureList[signWithKeyId];
   }
 
   if ((doLocalSig.checked) && (gExportableSignatureList[signWithKeyId] > 0)) {
     // User tries to locally sign a key he has already signed (at least partially) with an exportable signature
     // Here we display a hint and DISable the OK button
-    alreadySigned.setAttribute("value", EnigmailLocale.getString("alreadySignedexportable.label", "0x" + keyToBeSigned32));
+    alreadySigned.setAttribute("value", EnigmailLocale.getString("alreadySignedexportable.label", "0x" + keyToBeSigned));
     alreadySigned.removeAttribute("collapsed");
     acceptButton.disabled = true;
-  }
-  else if (signatureCount === undefined) {
+  } else if (signatureCount === undefined) {
     // No signature yet, Hide hint field and ENable OK button
     alreadySigned.setAttribute("collapsed", "true");
     acceptButton.disabled = false;
-  }
-  else if (signatureCount == gUidCount[keyToBeSigned]) {
+  } else if (signatureCount == gUidCount[keyToBeSigned]) {
     // Signature count == UID count, so key is already fully signed and another signing operation makes no more sense
     // Here, we display a hint and DISable the OK button
-    alreadySigned.setAttribute("value", EnigmailLocale.getString("alreadySigned.label", "0x" + keyToBeSigned32));
+    alreadySigned.setAttribute("value", EnigmailLocale.getString("alreadySigned.label", "0x" + keyToBeSigned));
     alreadySigned.removeAttribute("collapsed");
     acceptButton.disabled = true;
-  }
-  else if (signatureCount > 0) {
+  } else if (signatureCount > 0) {
     // Signature count != UID count, so key is partly signed and another sign operation makes sense
     // Here, we display a hint and ENable the OK button
-    alreadySigned.setAttribute("value", EnigmailLocale.getString("partlySigned.label", "0x" + keyToBeSigned32));
+    alreadySigned.setAttribute("value", EnigmailLocale.getString("partlySigned.label", "0x" + keyToBeSigned));
     alreadySigned.removeAttribute("collapsed");
     acceptButton.disabled = false;
-  }
-  else {
+  } else {
     // Default catch for unforeseen cases. Hide hint field and enable OK button
     alreadySigned.setAttribute("collapsed", "true");
     acceptButton.disabled = false;
   }
 }
+
+document.addEventListener("dialogaccept", function(event) {
+  if (!onAccept())
+    event.preventDefault(); // Prevent the dialog closing.
+});
\ No newline at end of file
