@@ -1,16 +1,17 @@
-/*global EnigInitCommon */
 /*
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at https://mozilla.org/MPL/2.0/.
  */
 
-// Uses: chrome://enigmail/content/enigmailCommon.js
-/* global EnigInitCommon: false, GetEnigmailSvc: false, EnigAlert: false, EnigGetString: false */
-/* global EnigConfirm: false, EnigmailLog: false, EnigmailKeyRing: false */
+// Uses: chrome://enigmail/content/ui/enigmailCommon.js
+/* global EnigInitCommon: false, GetEnigmailSvc: false, EnigGetString: false, EnigHelpWindow: false */
+/* global EnigConfirm: false, EnigmailLog: false, EnigmailKeyRing: false, EnigmailDialog: false */
 
 "use strict";
 
+var EnigmailRules = ChromeUtils.import("chrome://enigmail/content/modules/rules.jsm").EnigmailRules;
+
 // Initialize enigmailCommon
 EnigInitCommon("enigmailSingleRcptSettings");
 
@@ -18,6 +19,8 @@ const INPUT = 0;
 const RESULT = 1;
 
 function enigmailDlgOnLoad() {
+
+
   var matchBegin = false;
   var matchEnd = false;
 
@@ -32,14 +35,11 @@ function enigmailDlgOnLoad() {
   var matchingRule = document.getElementById("matchingRule");
   if (matchBegin && matchEnd) {
     matchingRule.selectedIndex = 0;
-  }
-  else if (matchBegin) {
+  } else if (matchBegin) {
     matchingRule.selectedIndex = 2;
-  }
-  else if (matchEnd) {
+  } else if (matchEnd) {
     matchingRule.selectedIndex = 3;
-  }
-  else {
+  } else {
     matchingRule.selectedIndex = 1;
   }
 
@@ -67,8 +67,7 @@ function enigmailDlgOnLoad() {
         enigSetKeys(window.arguments[INPUT].keyId);
         action = "actionUseKey";
     }
-  }
-  else {
+  } else {
     enigSetKeys("");
     action = "actionCont";
   }
@@ -82,20 +81,17 @@ function enigmailDlgOnLoad() {
 
   if (typeof(window.arguments[INPUT].sign) == "number") {
     document.getElementById("sign").selectedIndex = window.arguments[INPUT].sign;
-  }
-  else {
+  } else {
     document.getElementById("sign").selectedIndex = 1;
   }
   if (typeof(window.arguments[INPUT].encrypt) == "number") {
     document.getElementById("encrypt").selectedIndex = window.arguments[INPUT].encrypt;
-  }
-  else {
+  } else {
     document.getElementById("encrypt").selectedIndex = 1;
   }
   if (typeof(window.arguments[INPUT].pgpmime) == "number") {
     document.getElementById("pgpmime").selectedIndex = window.arguments[INPUT].pgpmime;
-  }
-  else {
+  } else {
     document.getElementById("pgpmime").selectedIndex = 1;
   }
 }
@@ -126,15 +122,15 @@ function enigmailDlgOnAccept() {
   // Remove trailing whitespace
   ruleEmail.value = ruleEmail.value.replace(/\s+$/, "").replace(/^\s+/, "");
   if (ruleEmail.value.length === 0) {
-    EnigAlert(EnigGetString("noEmptyRule"));
+    EnigmailDialog.info(window, EnigGetString("noEmptyRule"));
     return false;
   }
-  if (ruleEmail.value.search(/[<\>]/) >= 0) {
-    EnigAlert(EnigGetString("invalidAddress"));
+  if (ruleEmail.value.search(/[<>]/) >= 0) {
+    EnigmailDialog.info(window, EnigGetString("invalidAddress"));
     return false;
   }
   if (ruleEmail.value.search(/[{}]/) >= 0) {
-    EnigAlert(EnigGetString("noCurlyBrackets"));
+    EnigmailDialog.info(window, EnigGetString("noCurlyBrackets"));
     return false;
   }
   var encryptionList = document.getElementById("encryptionList");
@@ -175,14 +171,14 @@ function enigmailDlgOnAccept() {
 
   window.arguments[RESULT].cancelled = false;
   if (window.arguments[INPUT].options.indexOf("nosave") < 0) {
-    enigmailSvc.addRule(false,
+    EnigmailRules.addRule(false,
       window.arguments[RESULT].email,
       window.arguments[RESULT].keyId,
       window.arguments[RESULT].sign,
       window.arguments[RESULT].encrypt,
       window.arguments[RESULT].pgpMime,
       window.arguments[RESULT].negate);
-    enigmailSvc.saveRulesFile();
+    EnigmailRules.saveRulesFile();
   }
   return true;
 }
@@ -216,11 +212,10 @@ function enigmailDlgKeySelection() {
   inputObj.options += ",sendlabel=" + label;
   inputObj.options += ",";
 
-  window.openDialog("chrome://enigmail/content/enigmailKeySelection.xul", "", "dialog,modal,centerscreen,resizable", inputObj, resultObj);
+  window.openDialog("chrome://enigmail/content/ui/enigmailKeySelection.xul", "", "dialog,modal,centerscreen,resizable", inputObj, resultObj);
   try {
     if (resultObj.cancelled) return;
-  }
-  catch (ex) {
+  } catch (ex) {
     // cancel pressed -> do nothing
     return;
   }
@@ -229,24 +224,21 @@ function enigmailDlgKeySelection() {
 
 function enigSetKeys(keyList) {
   var encryptionList = document.getElementById("encryptionList");
-  while (encryptionList.getRowCount() > 0) {
-    encryptionList.removeItemAt(0);
+  while (encryptionList.firstChild) {
+    encryptionList.removeChild(encryptionList.firstChild);
   }
   if ((keyList.length === 0) || (keyList.length == 1 && keyList[0].length === 0)) {
     encryptionList.appendItem(EnigGetString("noKeyToUse"), "");
-  }
-  else {
+  } else {
     for (let i = 0; i < keyList.length; i++) {
 
       if (keyList[i].indexOf("GROUP:") === 0) {
         encryptionList.appendItem(keyList[i].substr(6) + " " + EnigGetString("keyTrust.group"), keyList[i]);
-      }
-      else {
+      } else {
         let keyObj = EnigmailKeyRing.getKeyById(keyList[i]);
         if (keyObj) {
-          encryptionList.appendItem("0x" + keyObj.keyId.substr(-8, 8) + " (" + keyObj.userId + ")", keyList[i]);
-        }
-        else {
+          encryptionList.appendItem("0x" + keyObj.keyId + " (" + keyObj.userId + ")", keyList[i]);
+        } else {
           encryptionList.appendItem(keyList[i], keyList[i]);
         }
       }
@@ -258,9 +250,19 @@ function enigEnableKeySel(enable) {
   if (enable) {
     document.getElementById("encryptionList").removeAttribute("disabled");
     document.getElementById("encryptionListButton").removeAttribute("disabled");
-  }
-  else {
+  } else {
     document.getElementById("encryptionList").setAttribute("disabled", "true");
     document.getElementById("encryptionListButton").setAttribute("disabled", "true");
   }
 }
+
+
+document.addEventListener("dialogaccept", function(event) {
+  if (!enigmailDlgOnAccept())
+    event.preventDefault(); // Prevent the dialog closing.
+});
+
+
+document.addEventListener("dialoghelp", function(event) {
+  EnigHelpWindow('editRcptRule');
+});
\ No newline at end of file
