@@ -1,18 +1,20 @@
 /*
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at https://mozilla.org/MPL/2.0/.
  */
 
-// Uses: chrome://enigmail/content/enigmailCommon.js
+// Uses: chrome://enigmail/content/ui/enigmailCommon.js
 
 /* global EnigmailLog: false */
 
 
 "use strict";
 
+
 function onLoad() {
   EnigmailLog.DEBUG("enigmailwrapSelection.js: onLoad\n");
+
   window.arguments[0].cancelled = true;
   window.arguments[0].Select = "";
 }
@@ -25,8 +27,7 @@ function onAccept() {
     window.arguments[0].Select = wrapSelect.value;
     window.arguments[0].cancelled = false;
     EnigmailLog.DEBUG("enigmailwrapSelection.js: onAccept, setting return value, disable cancel\n");
-  }
-  else {
+  } else {
     EnigmailLog.DEBUG("enigmailwrapSelection.js: onAccept, enable cancel\n");
     window.arguments[0].cancelled = true;
   }
@@ -36,3 +37,12 @@ function onCancel() {
   EnigmailLog.DEBUG("enigmailwrapSelection.js: onCancel, enable cancel\n");
   window.arguments[0].cancelled = true;
 }
+
+
+document.addEventListener("dialogaccept", function(event) {
+  onAccept();
+});
+
+document.addEventListener("dialogcancel", function(event) {
+  onCancel();
+});
\ No newline at end of file
