@@ -1,24 +1,26 @@
-/*global Components */
 /*
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at https://mozilla.org/MPL/2.0/.
  */
 
 
 /* global EnigmailLog: false, EnigmailLocale: false, EnigmailKey: false, EnigmailKeyRing: false */
 
 // from enigmailCommon.js:
-/* global GetEnigmailSvc: false, nsIEnigmail: false, EnigAlert: false, EnigConvertGpgToUnicode: false */
+/* global GetEnigmailSvc: false, EnigAlert: false, EnigConvertGpgToUnicode: false */
 /* global EnigCleanGuiList: false, EnigGetTrustLabel: false, EnigShowPhoto: false, EnigSignKey: false */
 /* global EnigEditKeyExpiry: false, EnigEditKeyTrust: false, EnigChangeKeyPwd: false, EnigRevokeKey: false */
-/* global EnigCreateRevokeCert: false */
+/* global EnigCreateRevokeCert: false, EnigmailTimer: false */
 
 // from enigmailKeyManager.js:
 /* global keyMgrAddPhoto: false */
 
 "use strict";
 
+
+
+
 var gKeyId = null;
 var gUserId = null;
 var gKeyList = null;
@@ -78,25 +80,35 @@ function reloadData() {
     if (keyObj.secretAvailable) {
       setLabel("keyType", EnigmailLocale.getString("keyTypePair"));
       document.getElementById("ownKeyCommands").removeAttribute("hidden");
-    }
-    else {
+    } else {
       document.getElementById("ownKeyCommands").setAttribute("hidden", "true");
       setLabel("keyType", EnigmailLocale.getString("keyTypePublic"));
     }
 
     if (keyObj.photoAvailable === true) {
-      photoImg.setAttribute("src", "enigmail://photo/0x" + gKeyId);
-      photoImg.removeAttribute("hidden");
-    }
-    else {
+      let pFile = keyObj.getPhotoFile(0);
+
+      if (pFile && pFile.isFile() && pFile.isReadable()) {
+        const photoUri = Cc["@mozilla.org/network/io-service;1"].
+        getService(Ci.nsIIOService).newFileURI(pFile).spec;
+
+        photoImg.setAttribute("src", photoUri);
+        photoImg.removeAttribute("hidden");
+      }
+    } else {
       photoImg.setAttribute("hidden", "true");
     }
 
+    if (keyObj.isOwnerTrustUseful()) {
+      document.getElementById("setOwnerTrust").removeAttribute("collapsed");
+    } else {
+      document.getElementById("setOwnerTrust").setAttribute("collapsed", "true");
+    }
+
     if (keyObj.hasSubUserIds()) {
       document.getElementById("alsoknown").removeAttribute("collapsed");
       createUidData(uidList, keyObj);
-    }
-    else {
+    } else {
       document.getElementById("alsoknown").setAttribute("collapsed", "true");
     }
 
@@ -105,10 +117,8 @@ function reloadData() {
       document.getElementById("signatures_tree").view = sigListViewObj;
     }
 
-    if (keyObj.subKeys.length > 0) {
-      let subkeyListViewObj = new SubkeyListView(keyObj);
-      document.getElementById("subkeyList").view = subkeyListViewObj;
-    }
+    let subkeyListViewObj = new SubkeyListView(keyObj);
+    document.getElementById("subkeyList").view = subkeyListViewObj;
 
     gUserId = keyObj.userId;
     let expiryDate = keyObj.expiry;
@@ -130,12 +140,11 @@ function reloadData() {
 function createUidData(listNode, keyDetails) {
   for (let i = 1; i < keyDetails.userIds.length; i++) {
     if (keyDetails.userIds[i].type === "uid") {
-      let item = document.createElement("listitem");
+      let item = listNode.appendItem(keyDetails.userIds[i].userId);
       item.setAttribute("label", keyDetails.userIds[i].userId);
       if ("dre".search(keyDetails.userIds[i].keyTrust) >= 0) {
-        item.setAttribute("disabled", "true");
+        item.setAttribute("class", "enigmailDisabled");
       }
-      listNode.appendChild(item);
     }
   }
 }
@@ -204,7 +213,7 @@ function manageUids() {
   var resultObj = {
     refresh: false
   };
-  window.openDialog("chrome://enigmail/content/enigmailManageUidDlg.xul",
+  window.openDialog("chrome://enigmail/content/ui/enigmailManageUidDlg.xul",
     "", "dialog,modal,centerscreen,resizable=yes", inputObj, resultObj);
   if (resultObj.refresh) {
     enableRefresh();
@@ -251,7 +260,7 @@ function SigListView(keyObj) {
           uid: s.userId,
           created: s.created,
           fpr: sig ? sig.fpr : "",
-          sigType: s.sigType,
+          sigType: s.sigType
         });
       }
     }
@@ -300,8 +309,7 @@ SigListView.prototype = {
 
         if (j + l >= row && row - j < l) {
           return this.setLastKeyObj(this.keyObj[i].sigList[row - j], row);
-        }
-        else {
+        } else {
           j += l;
         }
       }
@@ -405,15 +413,13 @@ function createSubkeyItem(subkey) {
   let expire;
   if (subkey.keyTrust === "r") {
     expire = EnigmailLocale.getString("keyValid.revoked");
-  }
-  else if (subkey.expiryTime === 0) {
+  } else if (subkey.expiryTime === 0) {
     expire = EnigmailLocale.getString("keyExpiryNever");
-  }
-  else {
+  } else {
     expire = subkey.expiry;
   }
 
-  let subkeyType = subkey.type === "pub" ? EnigmailLocale.getString("keyTypePublic") :
+  let subkeyType = subkey.type === "pub" ? EnigmailLocale.getString("keyTypePrimary") :
     EnigmailLocale.getString("keyTypeSubkey");
 
   let usagetext = "";
@@ -457,8 +463,8 @@ function createSubkeyItem(subkey) {
 
   let keyObj = {
     keyType: subkeyType,
-    keyId: "0x" + subkey.keyId.substr(-8, 8),
-    algo: EnigmailLocale.getString("keyAlgorithm_" + subkey.algorithm),
+    keyId: "0x" + subkey.keyId,
+    algo: subkey.algoSym,
     size: subkey.keySize,
     creationDate: subkey.created,
     expiry: expire,
@@ -564,4 +570,4 @@ SubkeyListView.prototype = {
   },
 
   toggleOpenState: function(row) {}
-};
+};
\ No newline at end of file
