@@ -1,32 +1,36 @@
 /*
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at https://mozilla.org/MPL/2.0/.
  */
 
-// Uses: chrome://enigmail/content/enigmailCommon.js
-/*global Components */
+// Uses: chrome://enigmail/content/ui/enigmailCommon.js
 
-/* global EnigmailLog: false, EnigmailLocale: false, EnigmailGpgAgent: false, EnigmailPrefs: false */
+/* global EnigmailLog: false, EnigmailLocale: false, EnigmailGpgAgent: false, EnigmailPrefs: false, EnigmailDialog: false */
 
 // from enigmailCommon.js:
 /* global EnigInitCommon: false, EnigGetPref: false, EnigSetPref: false, GetEnigmailSvc: false */
 /* global gEnigmailSvc: true, EnigGetString: false, EnigError: false, EnigGetVersion: false */
 /* global EnigGetDefaultPref: false, EnigConvertToUnicode: false, EnigCollapseAdvanced: false, EnigGetOS: false */
-/* global EnigGetFilePath: false, EnigAlert: false, EnigAlertPref: false, EnigFilePicker: false */
+/* global EnigGetFilePath: false, EnigAlertPref: false, EnigFilePicker: false */
 /* global EnigDisplayRadioPref: false, EnigSavePrefs: false, EnigConvertFromUnicode: false */
 /* global ENIG_C: false, ENIG_I: false, ENIG_ENIGMAIL_CONTRACTID: false */
-/* global gEnigEncryptionModel: true, gEnigAcceptedKeys: true, gEnigAutoSendEncrypted: true, gEnigConfirmBeforeSending: true */
+/* global gEnigAcceptedKeys: false, gEnigAutoSendEncrypted: true, gEnigConfirmBeforeSending: false */
 
 
 "use strict";
 
-Components.utils.import("resource://enigmail/configBackup.jsm"); /* global EnigmailConfigBackup: false */
+var EnigmailConfigBackup = ChromeUtils.import("chrome://enigmail/content/modules/configBackup.jsm").EnigmailConfigBackup;
+var EnigmailWindows = ChromeUtils.import("chrome://enigmail/content/modules/windows.jsm").EnigmailWindows;
+var EnigmailLazy = ChromeUtils.import("chrome://enigmail/content/modules/lazy.jsm").EnigmailLazy;
+
+const getCore = EnigmailLazy.loader("enigmail/core.jsm", "EnigmailCore");
 
 // Initialize enigmailCommon
 EnigInitCommon("pref-enigmail");
 
-var gMimePartsElement, gMimePartsValue, gAdvancedMode;
+var gMimePartsElement, gMimePartsValue, gAdvancedMode, gAcceptedKeyTypes, gAutoSendEncrypted,
+  gConfirmBeforeSending, gEncryptionModel;
 
 // saved old manual preferences to switch back
 // to them if we temporarily enabled convenient encryption
@@ -54,8 +58,7 @@ function displayPrefs(showDefault, showPrefs, setPrefs) {
       var prefValue;
       if (showDefault) {
         prefValue = EnigGetDefaultPref(prefName);
-      }
-      else {
+      } else {
         prefValue = EnigGetPref(prefName);
       }
 
@@ -69,8 +72,7 @@ function displayPrefs(showDefault, showPrefs, setPrefs) {
             }
             if (prefValue) {
               prefElement.setAttribute("checked", "true");
-            }
-            else {
+            } else {
               prefElement.removeAttribute("checked");
             }
           }
@@ -78,16 +80,13 @@ function displayPrefs(showDefault, showPrefs, setPrefs) {
             if (prefElement.getAttribute("invert") == "true") {
               if (prefElement.checked) {
                 EnigSetPref(prefName, false);
-              }
-              else {
+              } else {
                 EnigSetPref(prefName, true);
               }
-            }
-            else {
+            } else {
               if (prefElement.checked) {
                 EnigSetPref(prefName, true);
-              }
-              else {
+              } else {
                 EnigSetPref(prefName, false);
               }
             }
@@ -101,8 +100,7 @@ function displayPrefs(showDefault, showPrefs, setPrefs) {
           if (setPrefs) {
             try {
               EnigSetPref(prefName, 0 + prefElement.value);
-            }
-            catch (ex) {}
+            } catch (ex) {}
           }
           break;
 
@@ -125,16 +123,18 @@ function displayPrefs(showDefault, showPrefs, setPrefs) {
 function prefOnLoad() {
   EnigmailLog.DEBUG("pref-enigmail.js: prefOnLoad()\n");
 
+  document.getElementById("acSetupMessageDesc").innerHTML = EnigmailLocale.getString("acSetupMessage.desc");
+
   GetEnigmailSvc();
   displayPrefs(false, true, false);
 
   document.getElementById("enigmail_agentPath").value = EnigConvertToUnicode(EnigGetPref("agentPath"), "utf-8");
+  document.getElementById("protectedSubjectText").value = EnigConvertToUnicode(EnigGetPref("protectedSubjectText"), "utf-8");
 
   var maxIdle = -1;
   if (!gEnigmailSvc) {
     maxIdle = EnigmailPrefs.getPref("maxIdleMinutes");
-  }
-  else {
+  } else {
     maxIdle = EnigmailGpgAgent.getMaxIdlePref(window);
   }
 
@@ -148,8 +148,7 @@ function prefOnLoad() {
       document.getElementById("basic").setAttribute("collapsed", true);
       document.getElementById("basicTab").setAttribute("collapsed", true);
       selectPrefTabPanel("sendingTab");
-    }
-    else {
+    } else {
       EnigCollapseAdvanced(document.getElementById("prefTabBox"), "collapsed", null);
       //EnigCollapseAdvanced(document.getElementById("enigPrefTabPanel"), "hidden", null);
       enigShowUserModeButtons(gAdvancedMode);
@@ -159,31 +158,26 @@ function prefOnLoad() {
       selectPrefTabPanel(window.arguments[0].selectTab);
     }
 
-  }
-  else {
+  } else {
     enigShowUserModeButtons(gAdvancedMode);
   }
 
-  if (!EnigmailGpgAgent.gpgAgentIsOptional) {
-    document.getElementById("enigmail_noPassphrase").setAttribute("collapsed", true);
-    document.getElementById("enigmail_useGpgAgent").setAttribute("collapsed", true);
-  }
-
   if ((!window.arguments) || (window.arguments[0].clientType != "seamonkey")) {
     EnigCollapseAdvanced(document.getElementById("prefTabBox"), "collapsed", null);
     //EnigCollapseAdvanced(document.getElementById("enigPrefTabPanel"), "hidden", null);
   }
 
+  document.getElementById("enigmail_protectHeaders").checked = (EnigGetPref("protectedHeaders") === 2);
+
   // init "saved manual preferences" with current settings:
   gSavedManualPrefKeepSettingsForReply = EnigGetPref("keepSettingsForReply");
   gSavedManualPrefAcceptedKeys = EnigGetPref("acceptedKeys");
   gSavedManualPrefAutoSendEncrypted = EnigGetPref("autoSendEncrypted");
   gSavedManualPrefConfirmBeforeSending = EnigGetPref("confirmBeforeSending");
-  gEnigEncryptionModel = EnigGetPref("encryptionModel");
-  if (gEnigEncryptionModel === 0) { // convenient encryption
+  gEncryptionModel = EnigGetPref("encryptionModel");
+  if (gEncryptionModel === 0) { // convenient encryption
     resetSendingPrefsConvenient();
-  }
-  else {
+  } else {
     resetSendingPrefsManually();
   }
 
@@ -191,23 +185,20 @@ function prefOnLoad() {
 
   try {
     gMimePartsValue = EnigmailPrefs.getPrefRoot().getBoolPref("mail.server.default.mime_parts_on_demand");
-  }
-  catch (ex) {
+  } catch (ex) {
     gMimePartsValue = true;
   }
 
   if (gMimePartsValue) {
     gMimePartsElement.setAttribute("checked", "true");
-  }
-  else {
+  } else {
     gMimePartsElement.removeAttribute("checked");
   }
 
   var overrideGpg = document.getElementById("enigOverrideGpg");
   if (EnigGetPref("agentPath")) {
     overrideGpg.checked = true;
-  }
-  else {
+  } else {
     overrideGpg.checked = false;
   }
   enigActivateDependent(overrideGpg, "enigmail_agentPath enigmail_browsePath");
@@ -225,13 +216,12 @@ function prefOnLoad() {
 function enigDetermineGpgPath() {
   if (!gEnigmailSvc) {
     try {
-      gEnigmailSvc = ENIG_C[ENIG_ENIGMAIL_CONTRACTID].createInstance(ENIG_I.nsIEnigmail);
+      gEnigmailSvc = getCore().createInstance();
       if (!gEnigmailSvc.initialized) {
         // attempt to initialize Enigmail
         gEnigmailSvc.initialize(window, EnigGetVersion());
       }
-    }
-    catch (ex) {}
+    } catch (ex) {}
   }
 
   if (gEnigmailSvc.initialized && typeof(EnigmailGpgAgent.agentPath) == "object") {
@@ -239,8 +229,7 @@ function enigDetermineGpgPath() {
       var agentPath = "";
       if (EnigGetOS() == "WINNT") {
         agentPath = EnigGetFilePath(EnigmailGpgAgent.agentPath).replace(/\\\\/g, "\\");
-      }
-      else {
+      } else {
         agentPath = EnigmailGpgAgent.agentPath.path;
         // EnigGetFilePath(EnigmailGpgAgent.agentPath); // .replace(/\\\\/g, "\\");
       }
@@ -248,12 +237,10 @@ function enigDetermineGpgPath() {
         agentPath = agentPath.substring(0, 50) + "...";
       }
       document.getElementById("enigmailGpgPath").setAttribute("value", EnigGetString("prefs.gpgFound", agentPath));
-    }
-    catch (ex) {
+    } catch (ex) {
       document.getElementById("enigmailGpgPath").setAttribute("value", "error 2");
     }
-  }
-  else {
+  } else {
     document.getElementById("enigmailGpgPath").setAttribute("value", EnigGetString("prefs.gpgNotFound"));
   }
 }
@@ -277,11 +264,10 @@ function resetPrefs() {
   gSavedManualPrefAutoSendEncrypted = EnigGetPref("autoSendEncrypted");
   gSavedManualPrefConfirmBeforeSending = EnigGetPref("confirmBeforeSending");
   // and process encryption model:
-  gEnigEncryptionModel = EnigGetPref("encryptionModel");
-  if (gEnigEncryptionModel === 0) { // convenient encryption
+  gEncryptionModel = EnigGetPref("encryptionModel");
+  if (gEncryptionModel === 0) { // convenient encryption
     resetSendingPrefsConvenient();
-  }
-  else {
+  } else {
     resetSendingPrefsManually();
   }
 }
@@ -289,15 +275,13 @@ function resetPrefs() {
 // Serializes various Enigmail settings into a separate file.
 function backupPrefs() {
 
-  window.open("chrome://enigmail/content/exportSettingsWizard.xul",
+  window.open("chrome://enigmail/content/ui/exportSettingsWizard.xul",
     "", "chrome,centerscreen,resizable,modal");
 }
 
 
 function restorePrefs() {
-
-  window.open("chrome://enigmail/content/enigmailSetupWizard.xul?doRestore=true",
-    "", "chrome,centerscreen,resizable,modal");
+  EnigmailWindows.openImportSettings(window);
 }
 
 function disableManually(disable) {
@@ -311,15 +295,14 @@ function disableManually(disable) {
     "confirmBeforeSendingAlways",
     "confirmBeforeSendingIfEncrypted",
     "confirmBeforeSendingIfNotEncrypted",
-    "confirmBeforeSendingIfRules",
+    "confirmBeforeSendingIfRules"
   ];
   var elem;
   for (var i = 0; i < elems.length; ++i) {
     elem = document.getElementById(elems[i]);
     if (disable) {
       elem.setAttribute("disabled", "true");
-    }
-    else {
+    } else {
       elem.removeAttribute("disabled");
     }
   }
@@ -332,8 +315,8 @@ function updateSendingPrefs() {
     gEnigAutoSendEncrypted);
   EnigDisplayRadioPref("confirmBeforeSending", EnigGetPref("confirmBeforeSending"),
     gEnigConfirmBeforeSending);
-  gEnigEncryptionModel = EnigGetPref("encryptionModel");
-  disableManually(gEnigEncryptionModel === 0);
+  gEncryptionModel = EnigGetPref("encryptionModel");
+  disableManually(gEncryptionModel === 0);
   displayPrefs(false, true, false);
 }
 
@@ -347,18 +330,18 @@ function resetSendingPrefsConvenient() {
   gSavedManualPrefConfirmBeforeSending = document.getElementById("enigmail_confirmBeforeSending").value;
 
   // switch encryption model:
-  gEnigEncryptionModel = 0; // convenient encryption settings
-  EnigSetPref("encryptionModel", gEnigEncryptionModel);
+  gEncryptionModel = 0; // convenient encryption settings
+  EnigSetPref("encryptionModel", gEncryptionModel);
 
   // update GUI elements and corresponding setting variables:
   var keepSettingsForReply = true; // reply encrypted on encrypted emails
-  gEnigAcceptedKeys = 1; // all keys accepted
-  gEnigAutoSendEncrypted = 1; // auto.send-encrypted if accepted keys exist
-  gEnigConfirmBeforeSending = 0; // never confirm before sending
+  gAcceptedKeyTypes = 1; // all keys accepted
+  gAutoSendEncrypted = 1; // auto.send-encrypted if accepted keys exist
+  gConfirmBeforeSending = 0; // never confirm before sending
   EnigSetPref("keepSettingsForReply", keepSettingsForReply);
-  EnigSetPref("acceptedKeys", gEnigAcceptedKeys);
-  EnigSetPref("autoSendEncrypted", gEnigAutoSendEncrypted);
-  EnigSetPref("confirmBeforeSending", gEnigConfirmBeforeSending);
+  EnigSetPref("acceptedKeys", gAcceptedKeyTypes);
+  EnigSetPref("autoSendEncrypted", gAutoSendEncrypted);
+  EnigSetPref("confirmBeforeSending", gConfirmBeforeSending);
 
   updateSendingPrefs();
 }
@@ -367,19 +350,19 @@ function resetSendingPrefsManually() {
   EnigmailLog.DEBUG("pref-enigmail.js: resetSendingPrefsManually()\n");
 
   // switch encryption model:
-  gEnigEncryptionModel = 1; // manual encryption settings
-  EnigSetPref("encryptionModel", gEnigEncryptionModel);
+  gEncryptionModel = 1; // manual encryption settings
+  EnigSetPref("encryptionModel", gEncryptionModel);
 
   // update GUI elements and corresponding setting variables
   // with saved old manual preferences:
   var keepSettingsForReply = gSavedManualPrefKeepSettingsForReply;
-  gEnigAcceptedKeys = gSavedManualPrefAcceptedKeys;
-  gEnigAutoSendEncrypted = gSavedManualPrefAutoSendEncrypted;
-  gEnigConfirmBeforeSending = gSavedManualPrefConfirmBeforeSending;
+  gAcceptedKeyTypes = gSavedManualPrefAcceptedKeys;
+  gAutoSendEncrypted = gSavedManualPrefAutoSendEncrypted;
+  gConfirmBeforeSending = gSavedManualPrefConfirmBeforeSending;
   EnigSetPref("keepSettingsForReply", keepSettingsForReply);
-  EnigSetPref("acceptedKeys", gEnigAcceptedKeys);
-  EnigSetPref("autoSendEncrypted", gEnigAutoSendEncrypted);
-  EnigSetPref("confirmBeforeSending", gEnigConfirmBeforeSending);
+  EnigSetPref("acceptedKeys", gAcceptedKeyTypes);
+  EnigSetPref("autoSendEncrypted", gAutoSendEncrypted);
+  EnigSetPref("confirmBeforeSending", gConfirmBeforeSending);
 
   updateSendingPrefs();
 }
@@ -398,13 +381,14 @@ function resetRememberedValues() {
     "warnOnSendingNewsgroups",
     "warnDownloadContactKeys",
     "warnRefreshAll",
-    "warnDeprecatedGnuPG"
+    "warnDeprecatedGnuPG",
+    "warnOnMissingOwnerTrust"
   ];
 
   for (var j = 0; j < prefs.length; j++) {
     EnigSetPref(prefs[j], EnigGetDefaultPref(prefs[j]));
   }
-  EnigAlert(EnigGetString("warningsAreReset"));
+  EnigmailDialog.info(window, EnigGetString("warningsAreReset"));
 }
 
 function prefOnAccept() {
@@ -414,7 +398,7 @@ function prefOnAccept() {
   var autoKey = document.getElementById("enigmail_autoKeyRetrieve").value;
 
   if (autoKey.search(/.[ ,;\t]./) >= 0) {
-    EnigAlert(EnigGetString("prefEnigmail.oneKeyserverOnly"));
+    EnigmailDialog.info(window, EnigGetString("prefEnigmail.oneKeyserverOnly"));
     return false;
   }
 
@@ -424,9 +408,12 @@ function prefOnAccept() {
     document.getElementById("enigmail_agentPath").value = "";
   }
   var newAgentPath = document.getElementById("enigmail_agentPath").value;
+  var protectedSubjectText = document.getElementById("protectedSubjectText").value;
 
   displayPrefs(false, false, true);
   EnigSetPref("agentPath", EnigConvertFromUnicode(newAgentPath, "utf-8"));
+  EnigSetPref("protectedSubjectText", EnigConvertFromUnicode(protectedSubjectText, "utf-8"));
+
 
   if (gMimePartsElement &&
     (gMimePartsElement.checked != gMimePartsValue)) {
@@ -444,37 +431,40 @@ function prefOnAccept() {
     EnigmailGpgAgent.setMaxIdlePref(maxIdle);
   }
 
+  let protectionUndecided = (EnigGetPref("protectedHeaders") === 1);
+  let chk = document.getElementById("enigmail_protectHeaders").checked;
+
+  if (protectionUndecided && chk) {
+    EnigSetPref("protectedHeaders", 2);
+  } else if (!protectionUndecided) {
+    EnigSetPref("protectedHeaders", chk ? 2 : 0);
+  }
+
   EnigSavePrefs();
 
   if (oldAgentPath != newAgentPath) {
     if (!gEnigmailSvc) {
       try {
-        gEnigmailSvc = ENIG_C[ENIG_ENIGMAIL_CONTRACTID].createInstance(ENIG_I.nsIEnigmail);
-      }
-      catch (ex) {}
+        gEnigmailSvc = getCore().createInstance();
+      } catch (ex) {}
     }
 
     if (gEnigmailSvc.initialized) {
       try {
         gEnigmailSvc.reinitialize();
-      }
-      catch (ex) {
+      } catch (ex) {
         EnigError(EnigGetString("invalidGpgPath"));
       }
-    }
-    else {
+    } else {
       gEnigmailSvc = null;
       GetEnigmailSvc();
     }
   }
 
   // detect use of gpg-agent and warn if needed
-  if (EnigmailGpgAgent.useGpgAgent()) {
-    if (!EnigmailGpgAgent.isAgentTypeGpgAgent()) {
-      if ((document.getElementById("maxIdleMinutes").value > 0) &&
-        (!document.getElementById("enigmail_noPassphrase").checked)) {
-        EnigAlertPref(EnigGetString("prefs.warnIdleTimeForUnknownAgent"), "warnGpgAgentAndIdleTime");
-      }
+  if (!EnigmailGpgAgent.isAgentTypeGpgAgent()) {
+    if (document.getElementById("maxIdleMinutes").value > 0) {
+      EnigAlertPref(EnigGetString("prefs.warnIdleTimeForUnknownAgent"), "warnGpgAgentAndIdleTime");
     }
   }
 
@@ -492,8 +482,7 @@ function enigActivateDependent(obj, dependentIds) {
   for (depId in idList) {
     if (obj.checked) {
       document.getElementById(idList[depId]).removeAttribute("disabled");
-    }
-    else {
+    } else {
       document.getElementById(idList[depId]).setAttribute("disabled", "true");
     }
   }
@@ -506,8 +495,7 @@ function enigShowUserModeButtons(expertUser) {
   if (!expertUser) {
     basicUserButton.setAttribute("hidden", true);
     advUserButton.removeAttribute("hidden");
-  }
-  else {
+  } else {
     advUserButton.setAttribute("hidden", true);
     basicUserButton.removeAttribute("hidden");
   }
@@ -521,8 +509,7 @@ function enigSwitchAdvancedMode(expertUser) {
 
   if (expertUser) {
     EnigSetPref("advancedUser", true);
-  }
-  else {
+  } else {
     EnigSetPref("advancedUser", false);
   }
 
@@ -531,8 +518,7 @@ function enigSwitchAdvancedMode(expertUser) {
     // Thunderbird
     //    EnigCollapseAdvanced(document.getElementById("enigPrefTabPanel"), "hidden", null);
     EnigCollapseAdvanced(prefTabBox, "collapsed", null);
-  }
-  else {
+  } else {
     // Seamonkey
     EnigCollapseAdvanced(document.getElementById("enigmailPrefsBox"), "hidden", null);
   }
@@ -540,7 +526,7 @@ function enigSwitchAdvancedMode(expertUser) {
 }
 
 function enigAlertAskNever() {
-  EnigAlert(EnigGetString("prefs.warnAskNever"));
+  EnigmailDialog.info(window, EnigGetString("prefs.warnAskNever"));
 }
 
 function activateRulesButton(radioListObj, buttonId) {
@@ -554,6 +540,12 @@ function activateRulesButton(radioListObj, buttonId) {
   }
 }
 
+function handleClick(event) {
+  if (event.target.hasAttribute("href")) {
+    EnigmailWindows.openMailTab(event.target.getAttribute("href"));
+  }
+}
+
 
 function enigLocateGpg() {
   var fileName = "gpg";
@@ -571,3 +563,14 @@ function enigLocateGpg() {
     document.getElementById("enigmail_agentPath").value = filePath.path;
   }
 }
+
+
+function initiateAcKeyTransfer() {
+  EnigmailWindows.inititateAcSetupMessage();
+}
+
+
+document.addEventListener("dialogaccept", function(event) {
+  if (!prefOnAccept())
+    event.preventDefault();
+});
\ No newline at end of file
